@@ -14,7 +14,7 @@ from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING
 from ax.core.arm import Arm
 from ax.core.data import Data
 from ax.core.generator_run import GeneratorRun
-from ax.core.metric import Metric
+from ax.core.metric import Metric, MetricFetchResult
 from ax.core.runner import Runner
 from ax.core.types import TCandidateMetadata
 from ax.utils.common.base import SortableBase
@@ -464,7 +464,9 @@ class BaseTrial(ABC, SortableBase):
             self.mark_completed()
         return self
 
-    def fetch_data(self, metrics: Optional[List[Metric]] = None, **kwargs: Any) -> Data:
+    def fetch_data(
+        self, metrics: Optional[List[Metric]] = None, **kwargs: Any
+    ) -> Dict[str, MetricFetchResult]:
         """Fetch data for this trial for all metrics on experiment.
 
         Args:
