@@ -1,22 +1,24 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 from __future__ import annotations
 
-from collections import OrderedDict, defaultdict
+from collections import defaultdict, OrderedDict
 from dataclasses import dataclass
 from datetime import datetime
+from enum import Enum
+from logging import Logger
 from typing import (
-    TYPE_CHECKING,
     DefaultDict,
     Dict,
     List,
     MutableMapping,
     Optional,
     Set,
+    TYPE_CHECKING,
     Union,
 )
 
@@ -33,7 +35,7 @@ from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast, not_none
 
 
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 if TYPE_CHECKING:
@@ -41,6 +43,14 @@ if TYPE_CHECKING:
     from ax import core  # noqa F401  # pragma: no cover
 
 
+class LifecycleStage(int, Enum):
+    EXPLORATION = 0
+    ITERATION = 1
+    BAKEOFF = 2
+    OFFLINE_OPTIMIZED = 3
+    EXPLORATION_CONCURRENT = 4
+
+
 @dataclass
 class AbandonedArm(SortableBase):
     """Class storing metadata of arm that has been abandoned within
@@ -111,6 +121,8 @@ class BatchTrial(BaseTrial):
             This should generally not be specified, as in the index will be
             automatically determined based on the number of existing trials.
             This is only used for the purpose of loading from storage.
+        lifecycle_stage: The stage of the experiment lifecycle that this
+            trial represents
     """
 
     def __init__(
@@ -121,6 +133,7 @@ class BatchTrial(BaseTrial):
         optimize_for_power: Optional[bool] = False,
         ttl_seconds: Optional[int] = None,
         index: Optional[int] = None,
+        lifecycle_stage: Optional[LifecycleStage] = None,
     ) -> None:
         super().__init__(
             experiment=experiment,
@@ -154,6 +167,7 @@ class BatchTrial(BaseTrial):
         # for this object instead of one
         self._status_quo_generator_run_db_id: Optional[int] = None
         self._status_quo_arm_db_id: Optional[int] = None
+        self._lifecycle_stage = lifecycle_stage
 
     @property
     def experiment(self) -> core.experiment.Experiment:
@@ -198,6 +212,10 @@ class BatchTrial(BaseTrial):
             arm_weights[self.status_quo] = self._status_quo_weight_override
         return arm_weights
 
+    @property
+    def lifecycle_stage(self) -> Optional[LifecycleStage]:
+        return self._lifecycle_stage
+
     @arm_weights.setter
     def arm_weights(self, arm_weights: MutableMapping[Arm, float]) -> None:
         raise NotImplementedError("Use `trial.add_arms_and_weights`")
@@ -406,6 +424,14 @@ class BatchTrial(BaseTrial):
         """Set of names of arms that have been abandoned within this trial."""
         return set(self._abandoned_arms_metadata.keys())
 
+    @property
+    def in_design_arms(self) -> List[Arm]:
+        return [
+            arm
+            for arm in self.arms
+            if self.experiment.search_space.check_membership(arm.parameters)
+        ]
+
     # pyre-ignore[6]: T77111662.
     @copy_doc(BaseTrial.generator_runs)
     @property
@@ -466,7 +492,7 @@ class BatchTrial(BaseTrial):
         """
         weights = np.array(self.weights)
         if trunc_digits is not None:
-            atomic_weight = 10 ** -trunc_digits
+            atomic_weight = 10**-trunc_digits
             # pyre-fixme[16]: `float` has no attribute `astype`.
             int_weights = (
                 (total / atomic_weight) * (weights / np.sum(weights))
