@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -7,6 +7,7 @@
 from __future__ import annotations
 
 import warnings
+from logging import Logger
 from typing import Any, Iterable, List, Optional, Tuple
 
 from ax.core.metric import Metric
@@ -14,8 +15,7 @@ from ax.utils.common.base import SortableBase
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import not_none
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 class Objective(SortableBase):
@@ -60,6 +60,7 @@ class Objective(SortableBase):
                     "`lower_is_better=False`."
                 )
         self._metric = metric
+        # pyre-fixme[4]: Attribute must be annotated.
         self.minimize = not_none(minimize)
 
     @property
@@ -72,6 +73,11 @@ class Objective(SortableBase):
         """Get a list of objective metrics."""
         return [self._metric]
 
+    @property
+    def metric_names(self) -> List[str]:
+        """Get a list of objective metric names."""
+        return [m.name for m in self.metrics]
+
     def clone(self) -> Objective:
         """Create a copy of the objective."""
         return Objective(self.metric.clone(), self.minimize)
@@ -135,6 +141,7 @@ class MultiObjective(Objective):
                 _minimize = not lower_is_better if minimize else lower_is_better
                 objectives.append(Objective(metric=metric, minimize=_minimize))
 
+        # pyre-fixme[4]: Attribute must be annotated.
         self._objectives = not_none(objectives)
 
         # For now, assume all objectives are weighted equally.
@@ -171,10 +178,6 @@ class MultiObjective(Objective):
     def __repr__(self) -> str:
         return f"MultiObjective(objectives={self.objectives})"
 
-    def get_unconstrainable_metrics(self) -> List[Metric]:
-        """Return a list of metrics that are incompatible with OutcomeConstraints."""
-        return []
-
 
 class ScalarizedObjective(Objective):
     """Class for an objective composed of a linear scalarization of metrics.
@@ -239,7 +242,3 @@ class ScalarizedObjective(Objective):
         return "ScalarizedObjective(metric_names={}, weights={}, minimize={})".format(
             [metric.name for metric in self.metrics], self.weights, self.minimize
         )
-
-    def get_unconstrainable_metrics(self) -> List[Metric]:
-        """Return a list of metrics that are incompatible with OutcomeConstraints."""
-        return []
