@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -106,6 +106,28 @@ class OptimizationComplete(AxError):
         )
 
 
+class OptimizationShouldStop(OptimizationComplete):
+    """Raised when the Global Stopping Strategy suggests to stop the optimization."""
+
+    def __init__(self, message: str) -> None:
+        super().__init__(
+            message=message
+            or "The Global Stopping Strategy has decided to stop the optimization."
+        )
+
+
+class ObjectNotFoundError(AxError, ValueError):
+    """Raised when an object is not found in the database.
+
+    This exception replaces ValueError raised by code when an objects is not
+    found in the database. In order to maintain backwards compatibility
+    ObjectNotFoundError inherits from ValueError. Dependency on ValueError
+    may be removed in the future.
+    """
+
+    pass
+
+
 class SearchSpaceExhausted(OptimizationComplete):
     """Raised when using an algorithm that deduplicates points and no more
     new points can be sampled from the search space."""
