@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -8,24 +8,21 @@
 from ax.modelbridge import transforms
 from ax.modelbridge.base import ModelBridge
 from ax.modelbridge.factory import (
-    Models,
     get_factorial,
     get_GPEI,
     get_sobol,
     get_thompson,
     get_uniform,
+    Models,
 )
-from ax.modelbridge.multi_objective_torch import MultiObjectiveTorchModelBridge
-from ax.modelbridge.numpy import NumpyModelBridge
+from ax.modelbridge.map_torch import MapTorchModelBridge
 from ax.modelbridge.torch import TorchModelBridge
 
-
 __all__ = [
+    "MapTorchModelBridge",
     "ModelBridge",
     "Models",
-    "NumpyModelBridge",
     "TorchModelBridge",
-    "MultiObjectiveTorchModelBridge",
     "get_factorial",
     "get_GPEI",
     "get_GPKG",
