@@ -1,68 +1,9 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from __future__ import annotations
-
-from enum import Enum
-from inspect import isfunction, signature
-from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Type
-
-import torch
-from ax.core.data import Data
-from ax.core.experiment import Experiment
-from ax.core.generator_run import GeneratorRun
-from ax.core.search_space import SearchSpace
-from ax.modelbridge.base import ModelBridge
-from ax.modelbridge.discrete import DiscreteModelBridge
-from ax.modelbridge.multi_objective_torch import MultiObjectiveTorchModelBridge
-from ax.modelbridge.random import RandomModelBridge
-from ax.modelbridge.torch import TorchModelBridge
-from ax.modelbridge.transforms.base import Transform
-from ax.modelbridge.transforms.centered_unit_x import CenteredUnitX
-from ax.modelbridge.transforms.choice_encode import OrderedChoiceEncode, ChoiceEncode
-from ax.modelbridge.transforms.convert_metric_names import ConvertMetricNames
-from ax.modelbridge.transforms.derelativize import Derelativize
-from ax.modelbridge.transforms.int_range_to_choice import IntRangeToChoice
-from ax.modelbridge.transforms.int_to_float import IntToFloat
-from ax.modelbridge.transforms.ivw import IVW
-from ax.modelbridge.transforms.log import Log
-from ax.modelbridge.transforms.one_hot import OneHot
-from ax.modelbridge.transforms.remove_fixed import RemoveFixed
-from ax.modelbridge.transforms.search_space_to_choice import SearchSpaceToChoice
-from ax.modelbridge.transforms.standardize_y import StandardizeY
-from ax.modelbridge.transforms.stratified_standardize_y import StratifiedStandardizeY
-from ax.modelbridge.transforms.task_encode import TaskEncode
-from ax.modelbridge.transforms.trial_as_task import TrialAsTask
-from ax.modelbridge.transforms.unit_x import UnitX
-from ax.models.base import Model
-from ax.models.discrete.eb_thompson import EmpiricalBayesThompsonSampler
-from ax.models.discrete.full_factorial import FullFactorialGenerator
-from ax.models.discrete.thompson import ThompsonSampler
-from ax.models.random.sobol import SobolGenerator
-from ax.models.random.uniform import UniformGenerator
-from ax.models.torch.alebo import ALEBO
-from ax.models.torch.botorch import BotorchModel
-from ax.models.torch.botorch_kg import KnowledgeGradient
-from ax.models.torch.botorch_mes import MaxValueEntropySearch
-from ax.models.torch.botorch_modular.model import BoTorchModel as ModularBoTorchModel
-from ax.models.torch.botorch_moo import MultiObjectiveBotorchModel
-from ax.utils.common.kwargs import (
-    consolidate_kwargs,
-    get_function_argument_names,
-    get_function_default_arguments,
-    validate_kwarg_typing,
-)
-from ax.utils.common.logger import get_logger
-from ax.utils.common.serialization import callable_from_reference, callable_to_reference
-from ax.utils.common.typeutils import checked_cast, not_none
-
-
-logger = get_logger(__name__)
-
-
 """
 Module containing a registry of standard models (and generators, samplers etc.)
 such as Sobol generator, GP+EI, Thompson sampler, etc.
@@ -73,12 +14,79 @@ from generator run, use `get_model_from_generator_run` utility from this module.
 """
 
 
+from __future__ import annotations
+
+from enum import Enum
+from inspect import isfunction, signature
+
+from logging import Logger
+from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Type
+
+import torch
+from ax.core.data import Data
+from ax.core.experiment import Experiment
+from ax.core.generator_run import GeneratorRun
+from ax.core.search_space import SearchSpace
+from ax.modelbridge.base import ModelBridge
+from ax.modelbridge.discrete import DiscreteModelBridge
+from ax.modelbridge.random import RandomModelBridge
+from ax.modelbridge.torch import TorchModelBridge
+from ax.modelbridge.transforms.base import Transform
+from ax.modelbridge.transforms.centered_unit_x import CenteredUnitX
+from ax.modelbridge.transforms.choice_encode import ChoiceEncode, OrderedChoiceEncode
+from ax.modelbridge.transforms.convert_metric_names import ConvertMetricNames
+from ax.modelbridge.transforms.derelativize import Derelativize
+from ax.modelbridge.transforms.int_range_to_choice import IntRangeToChoice
+from ax.modelbridge.transforms.int_to_float import IntToFloat
+from ax.modelbridge.transforms.ivw import IVW
+from ax.modelbridge.transforms.log import Log
+from ax.modelbridge.transforms.logit import Logit
+from ax.modelbridge.transforms.one_hot import OneHot
+from ax.modelbridge.transforms.relativize import Relativize
+from ax.modelbridge.transforms.remove_fixed import RemoveFixed
+from ax.modelbridge.transforms.search_space_to_choice import SearchSpaceToChoice
+from ax.modelbridge.transforms.standardize_y import StandardizeY
+from ax.modelbridge.transforms.stratified_standardize_y import StratifiedStandardizeY
+from ax.modelbridge.transforms.task_encode import TaskEncode
+from ax.modelbridge.transforms.trial_as_task import TrialAsTask
+from ax.modelbridge.transforms.unit_x import UnitX
+from ax.models.base import Model
+from ax.models.discrete.eb_thompson import EmpiricalBayesThompsonSampler
+from ax.models.discrete.full_factorial import FullFactorialGenerator
+from ax.models.discrete.thompson import ThompsonSampler
+from ax.models.random.alebo_initializer import ALEBOInitializer
+from ax.models.random.sobol import SobolGenerator
+from ax.models.random.uniform import UniformGenerator
+from ax.models.torch.alebo import ALEBO
+from ax.models.torch.botorch import BotorchModel
+from ax.models.torch.botorch_kg import KnowledgeGradient
+from ax.models.torch.botorch_mes import MaxValueEntropySearch
+from ax.models.torch.botorch_modular.model import BoTorchModel as ModularBoTorchModel
+from ax.models.torch.botorch_moo import MultiObjectiveBotorchModel
+from ax.models.torch.cbo_sac import SACBO
+from ax.models.torch.fully_bayesian import (
+    FullyBayesianBotorchModel,
+    FullyBayesianMOOBotorchModel,
+)
+from ax.utils.common.kwargs import (
+    consolidate_kwargs,
+    get_function_argument_names,
+    get_function_default_arguments,
+    validate_kwarg_typing,
+)
+from ax.utils.common.logger import get_logger
+from ax.utils.common.serialization import callable_from_reference, callable_to_reference
+from ax.utils.common.typeutils import checked_cast, not_none
+
+logger: Logger = get_logger(__name__)
+
 Cont_X_trans: List[Type[Transform]] = [
     RemoveFixed,
     OrderedChoiceEncode,
     OneHot,
     IntToFloat,
     Log,
+    Logit,
     UnitX,
 ]
 
@@ -89,9 +97,12 @@ Mixed_transforms: List[Type[Transform]] = [
     ChoiceEncode,
     IntToFloat,
     Log,
+    Logit,
     UnitX,
 ]
 
+EB_ashr_trans: List[Type[Transform]] = [Relativize, IVW, SearchSpaceToChoice]
+
 Y_trans: List[Type[Transform]] = [IVW, Derelativize, StandardizeY]
 
 # Expected `List[Type[Transform]]` for 2nd anonymous parameter to
@@ -203,13 +214,13 @@ MODEL_KEY_TO_MODEL_SETUP: Dict[str, ModelSetup] = {
         transforms=Cont_X_trans,
     ),
     "MOO": ModelSetup(
-        bridge_class=MultiObjectiveTorchModelBridge,
+        bridge_class=TorchModelBridge,
         model_class=MultiObjectiveBotorchModel,
         transforms=Cont_X_trans + Y_trans,
         standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
     ),
     "MOO_Modular": ModelSetup(
-        bridge_class=MultiObjectiveTorchModelBridge,
+        bridge_class=TorchModelBridge,
         model_class=ModularBoTorchModel,
         transforms=Cont_X_trans + Y_trans,
         standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
@@ -224,6 +235,12 @@ MODEL_KEY_TO_MODEL_SETUP: Dict[str, ModelSetup] = {
         bridge_class=TorchModelBridge,
         model_class=ALEBO,
         transforms=ALEBO_X_trans + ALEBO_Y_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "ALEBO_Initializer": ModelSetup(
+        bridge_class=RandomModelBridge,
+        model_class=ALEBOInitializer,
+        transforms=ALEBO_X_trans,
     ),
     "BO_MIXED": ModelSetup(
         bridge_class=TorchModelBridge,
@@ -231,6 +248,42 @@ MODEL_KEY_TO_MODEL_SETUP: Dict[str, ModelSetup] = {
         transforms=Mixed_transforms + Y_trans,
         standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
     ),
+    "FullyBayesian": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=FullyBayesianBotorchModel,
+        transforms=Cont_X_trans + Y_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "FullyBayesianMOO": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=FullyBayesianMOOBotorchModel,
+        transforms=Cont_X_trans + Y_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "FullyBayesian_MTGP": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=FullyBayesianBotorchModel,
+        transforms=ST_MTGP_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "FullyBayesianMOO_MTGP": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=FullyBayesianMOOBotorchModel,
+        transforms=ST_MTGP_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "ST_MTGP_NEHVI": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=MultiObjectiveBotorchModel,
+        transforms=ST_MTGP_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
+    "Contextual_SACBO": ModelSetup(
+        bridge_class=TorchModelBridge,
+        model_class=SACBO,
+        transforms=Cont_X_trans + Y_trans,
+        standard_bridge_kwargs=STANDARD_TORCH_BRIDGE_KWARGS,
+    ),
 }
 
 
@@ -303,8 +356,8 @@ class ModelRegistryBase(Enum):
         )
 
         if model_setup_info.not_saved_model_kwargs:
-            for key in model_setup_info.not_saved_model_kwargs:
-                model_kwargs.pop(key, None)
+            for key in model_setup_info.not_saved_model_kwargs:  # pragma: no cover
+                model_kwargs.pop(key, None)  # pragma: no cover
 
         # Store all kwargs on model bridge, to be saved on generator run.
         model_bridge._set_kwargs_to_save(
@@ -390,6 +443,10 @@ class Models(ModelRegistryBase):
     GPKG = "GPKG"
     GPMES = "GPMES"
     FACTORIAL = "Factorial"
+    FULLYBAYESIAN = "FullyBayesian"
+    FULLYBAYESIANMOO = "FullyBayesianMOO"
+    FULLYBAYESIAN_MTGP = "FullyBayesian_MTGP"
+    FULLYBAYESIANMOO_MTGP = "FullyBayesianMOO_MTGP"
     THOMPSON = "Thompson"
     BOTORCH = "BO"
     BOTORCH_MODULAR = "BoTorch"
@@ -400,13 +457,16 @@ class Models(ModelRegistryBase):
     ST_MTGP = "ST_MTGP"
     ALEBO = "ALEBO"
     BO_MIXED = "BO_MIXED"
+    ST_MTGP_NEHVI = "ST_MTGP_NEHVI"
+    ALEBO_INITIALIZER = "ALEBO_Initializer"
+    CONTEXT_SACBO = "Contextual_SACBO"
 
 
 def get_model_from_generator_run(
     generator_run: GeneratorRun,
     experiment: Experiment,
     data: Data,
-    models_enum: Optional[Type[ModelRegistryBase]] = None,
+    models_enum: Type[ModelRegistryBase],
     after_gen: bool = True,
 ) -> ModelBridge:
     """Reinstantiate a model from model key and kwargs stored on a given generator
@@ -420,7 +480,7 @@ def get_model_from_generator_run(
             reinstantiate.
         experiment: The experiment for which the model is reinstantiated.
         data: Data, with which to reinstantiate the model.
-        models_enum: Optional subclass of `Models` registry, from which to obtain
+        models_enum: Subclass of `Models` registry, from which to obtain
             the settings of the model. Useful only if the generator run was
             created via a model that could not be included into the main registry,
             but can still be represented as a `ModelSetup` and was added to a
@@ -436,7 +496,7 @@ def get_model_from_generator_run(
             "Cannot restore model from generator run as no model key was "
             "on the generator run stored."
         )
-    model = (models_enum or Models)(generator_run._model_key)
+    model = models_enum(generator_run._model_key)
     model_kwargs = generator_run._model_kwargs or {}
     if after_gen:
         model_kwargs = _combine_model_kwargs_and_state(
@@ -469,12 +529,29 @@ def _combine_model_kwargs_and_state(
     """
     model_kwargs = model_kwargs or generator_run._model_kwargs or {}
     if generator_run._model_state_after_gen is None:
-        return model_kwargs
+        return model_kwargs  # pragma: no cover
 
+    # We don't want to update `model_kwargs` on the `GenerationStep`,
+    # just to add to them for the purpose of this function.
+    return {
+        **model_kwargs,
+        **_extract_model_state_after_gen(
+            generator_run=generator_run, model_class=model_class
+        ),
+    }
+
+
+def _extract_model_state_after_gen(
+    generator_run: GeneratorRun, model_class: Type[Model]
+) -> Dict[str, Any]:
+    """Extracts serialized post-generation model state from a generator run and
+    deserializes it. Fails if no post-generation model state was specified on the
+    generator run.
+    """
     serialized_model_state = not_none(generator_run._model_state_after_gen)
     # We don't want to update `model_kwargs` on the `GenerationStep`,
     # just to add to them for the purpose of this function.
-    return {**model_kwargs, **model_class.deserialize_state(serialized_model_state)}
+    return model_class.deserialize_state(serialized_model_state)
 
 
 def _encode_callables_as_references(kwarg_dict: Dict[str, Any]) -> Dict[str, Any]:
