@@ -6,6 +6,7 @@
 
 import warnings
 from unittest import mock
+from unittest.mock import Mock
 
 import numpy as np
 import pandas as pd
@@ -21,6 +22,7 @@ from ax.core.observation import (
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.parameter import FixedParameter, ParameterType, RangeParameter
 from ax.core.search_space import SearchSpace
+from ax.exceptions.core import UserInputError
 from ax.modelbridge.base import (
     clamp_observation_features,
     gen_arms,
@@ -38,6 +40,7 @@ from ax.utils.testing.core_stubs import (
     get_experiment,
     get_experiment_with_repeated_arms,
     get_non_monolithic_branin_moo_data,
+    get_optimization_config,
     get_optimization_config_no_constraints,
     get_search_space_for_range_value,
     get_search_space_for_range_values,
@@ -68,9 +71,9 @@ class BaseModelBridgeTest(TestCase):
         return_value=([Arm(parameters={})], None),
     )
     @mock.patch("ax.modelbridge.base.ModelBridge._fit", autospec=True)
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def testModelBridge(self, mock_fit, mock_gen_arms, mock_observations_from_data):
+    def test_ModelBridge(
+        self, mock_fit: Mock, mock_gen_arms: Mock, mock_observations_from_data: Mock
+    ) -> None:
         # Test that on init transforms are stored and applied in the correct order
         transforms = [transform_1, transform_2]
         exp = get_experiment_for_value()
@@ -154,6 +157,9 @@ class BaseModelBridgeTest(TestCase):
         modelbridge._set_kwargs_to_save(
             model_key="TestModel", model_kwargs={}, bridge_kwargs={}
         )
+        # Test input error when generating 0 candidates.
+        with self.assertRaisesRegex(UserInputError, "Attempted to generate"):
+            modelbridge.gen(n=0)
         gr = modelbridge.gen(
             n=1,
             search_space=get_search_space_for_value(),
@@ -257,8 +263,7 @@ class BaseModelBridgeTest(TestCase):
         autospec=True,
         return_value=([get_observation1(), get_observation2()]),
     )
-    # pyre-fixme[3]: Return type must be annotated.
-    def test_ood_gen(self, _):
+    def test_ood_gen(self, _) -> None:
         # Test fit_out_of_design by returning OOD candidats
         exp = get_experiment_for_value()
         ss = SearchSpace([RangeParameter("x", ParameterType.FLOAT, 0.0, 1.0)])
@@ -454,6 +459,17 @@ class BaseModelBridgeTest(TestCase):
         if len(exp.trials) >= 1:
             self.assertEqual(modelbridge.status_quo, get_observation_status_quo1())
 
+    def test_transform_observations(self) -> None:
+        """
+        This functionality is unused, even in the subclass where it is implemented.
+        """
+        ss = get_search_space_for_value()
+        modelbridge = ModelBridge(search_space=ss, model=Model())
+        with self.assertRaises(NotImplementedError):
+            modelbridge.transform_observations([])
+        with self.assertRaises(NotImplementedError):
+            modelbridge.transform_observations([])
+
     @mock.patch(
         "ax.modelbridge.base.observations_from_data",
         autospec=True,
@@ -558,6 +574,26 @@ class BaseModelBridgeTest(TestCase):
             pending_observations={},
         )
 
+    def test_transform_optimization_config(self) -> None:
+        """
+        The tested functionality is unused and is likely to be deprecated or
+        removed, hence this test exists only to unbreak
+        a failing codecov test. It is not an ideal test since we are using
+        empty `fixed_features` and `transforms`.
+        """
+        ss = get_search_space_for_range_value()
+        modelbridge = ModelBridge(search_space=ss, model=Model)
+
+        fixed_features = ObservationFeatures(parameters={})
+        optimization_config = get_optimization_config()
+        new_cfg = modelbridge.transform_optimization_config(
+            optimization_config, fixed_features
+        )
+        # In this case no transformations were applied, so config doesn't change
+        self.assertEqual(optimization_config, new_cfg)
+        # Even if no transforms were applied, method should return a new object
+        self.assertFalse(optimization_config is new_cfg)
+
     @mock.patch(
         "ax.modelbridge.base.ModelBridge._gen",
         autospec=True,
