@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -13,10 +13,10 @@ from ax.utils.common.testutils import TestCase
 
 
 class RoundingTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         pass
 
-    def testOneHotRound(self):
+    def testOneHotRound(self) -> None:
         self.assertTrue(
             np.allclose(
                 strict_onehot_round(np.array([0.1, 0.5, 0.3])), np.array([0, 1, 0])
