@@ -19,6 +19,7 @@ from ax.core.outcome_constraint import (
     OutcomeConstraint,
 )
 from ax.core.parameter_constraint import ParameterConstraint
+from ax.exceptions.core import UnsupportedError
 from ax.modelbridge.factory import get_sobol
 from ax.modelbridge.modelbridge_utils import (
     get_pareto_frontier_and_configs,
@@ -37,6 +38,7 @@ from ax.models.torch.botorch_moo_defaults import (
 )
 from ax.service.utils.report_utils import exp_to_df
 from ax.utils.common.testutils import TestCase
+from ax.utils.common.typeutils import not_none
 from ax.utils.testing.core_stubs import (
     get_branin_data_multi_objective,
     get_branin_experiment_with_multi_objective,
@@ -48,7 +50,7 @@ from ax.utils.testing.modeling_stubs import transform_1, transform_2
 from botorch.utils.multi_objective.pareto import is_non_dominated
 
 PARETO_FRONTIER_EVALUATOR_PATH = (
-    f"{pareto_frontier_evaluator.__module__}.pareto_frontier_evaluator"
+    f"{get_pareto_frontier_and_configs.__module__}.pareto_frontier_evaluator"
 )
 STUBS_PATH: str = get_branin_experiment_with_multi_objective.__module__
 
@@ -75,8 +77,7 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
         )
         for trial in exp.trials.values():
             trial.mark_running(no_runner_required=True).mark_completed()
-        # pyre-fixme[16]: Optional type has no attribute `metrics`.
-        metrics_dict = exp.optimization_config.metrics
+        metrics_dict = not_none(exp.optimization_config).metrics
         objective_thresholds = [
             ObjectiveThreshold(
                 metric=metrics_dict[f"branin_{letter}"],
@@ -110,16 +111,14 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
         with patch(
             PARETO_FRONTIER_EVALUATOR_PATH, wraps=pareto_frontier_evaluator
         ) as wrapped_frontier_evaluator:
-            # pyre-fixme[16]: Optional type has no attribute `frontier_evaluator`.
-            # pyre-fixme[16]: `TorchModel` has no attribute `frontier_evaluator`.
-            modelbridge.model.frontier_evaluator = wrapped_frontier_evaluator
             observed_frontier = observed_pareto_frontier(
                 modelbridge=modelbridge, objective_thresholds=objective_thresholds
             )
-            wrapped_frontier_evaluator.assert_called_once()
-            self.assertIsNone(wrapped_frontier_evaluator.call_args[1]["X"])
-            self.assertEqual(1, len(observed_frontier))
-            self.assertEqual(observed_frontier[0].arm_name, "0_0")
+
+        wrapped_frontier_evaluator.assert_called_once()
+        self.assertIsNone(wrapped_frontier_evaluator.call_args[1]["X"])
+        self.assertEqual(1, len(observed_frontier))
+        self.assertEqual(observed_frontier[0].arm_name, "0_0")
 
         with self.assertRaises(ValueError):
             predicted_pareto_frontier(
@@ -137,7 +136,9 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
 
         observation_features = [
             ObservationFeatures(parameters={"x1": 0.0, "x2": 1.0}),
-            ObservationFeatures(parameters={"x1": 1.0, "x2": 0.0}),
+            # magic number to ensure the model makes one non-negative
+            # prediction, so there is a point within the thresholds
+            ObservationFeatures(parameters={"x1": -2.0, "x2": 6.3}),
         ]
         extra_outcome = ["branin_c"] if outcome_constraints is not None else []
         observation_data = [
@@ -171,29 +172,26 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
                 objective_thresholds=objective_thresholds,
                 observation_features=observation_features,
                 observation_data=observation_data,
+                use_model_predictions=False,
             )
-            wrapped_frontier_evaluator.assert_called_once()
-            self.assertTrue(
-                torch.equal(
-                    wrapped_frontier_evaluator.call_args[1]["X"],
-                    torch.tensor([[1.0, 4.0], [4.0, 1.0]], dtype=torch.double),
-                )
+
+        wrapped_frontier_evaluator.assert_called_once()
+        self.assertEqual(f.shape, (1, n_outcomes))
+        self.assertTrue(torch.equal(obj_w[:2], torch.ones(2, dtype=torch.double)))
+        self.assertTrue(obj_t is not None)
+        self.assertTrue(
+            torch.equal(
+                not_none(obj_t)[:2], torch.tensor([0.0, 0.0], dtype=torch.double)
             )
-            self.assertEqual(f.shape, (1, n_outcomes))
-            self.assertTrue(torch.equal(obj_w[:2], torch.ones(2, dtype=torch.double)))
-            self.assertTrue(obj_t is not None)
-            # obj_t isn't None; this is just to appease Pyre
-            if obj_t is not None:
-                self.assertTrue(
-                    torch.equal(obj_t[:2], torch.tensor([0.0, 0.0], dtype=torch.double))
-                )
-            observed_frontier2 = pareto_frontier(
-                modelbridge=modelbridge,
-                objective_thresholds=objective_thresholds,
-                observation_features=observation_features,
-                observation_data=observation_data,
-            )
-            self.assertEqual(observed_frontier, observed_frontier2)
+        )
+        observed_frontier2 = pareto_frontier(
+            modelbridge=modelbridge,
+            objective_thresholds=objective_thresholds,
+            observation_features=observation_features,
+            observation_data=observation_data,
+            use_model_predictions=False,
+        )
+        self.assertEqual(observed_frontier, observed_frontier2)
 
         with patch(
             PARETO_FRONTIER_EVALUATOR_PATH, wraps=pareto_frontier_evaluator
@@ -205,16 +203,16 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
                 observation_data=observation_data,
                 use_model_predictions=False,
             )
-            wrapped_frontier_evaluator.assert_called_once()
-            self.assertIsNone(wrapped_frontier_evaluator.call_args[1]["X"])
-            true_Y = torch.tensor([[9.0, 4.0], [16.0, 25.0]], dtype=torch.double)
-            self.assertTrue(
-                torch.equal(
-                    wrapped_frontier_evaluator.call_args[1]["Y"][:, :2],
-                    true_Y,
-                )
+        wrapped_frontier_evaluator.assert_called_once()
+        self.assertIsNone(wrapped_frontier_evaluator.call_args[1]["X"])
+        true_Y = torch.tensor([[2.0, 1.0], [3.0, 4.0]], dtype=torch.double)
+        self.assertTrue(
+            torch.equal(
+                wrapped_frontier_evaluator.call_args[1]["Y"][:, :2],
+                true_Y,
             )
-            self.assertTrue(torch.equal(f[:, :2], true_Y[1:, :]))
+        )
+        self.assertTrue(torch.equal(f[:, :2], true_Y[1:, :]))
 
     def test_pareto_frontier(self) -> None:
         """
@@ -231,6 +229,100 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
                     outcome_constraints=outcome_constraints
                 )
 
+    @fast_botorch_optimize
+    def test_get_pareto_frontier_and_configs_input_validation(self) -> None:
+
+        exp = get_branin_experiment_with_multi_objective(
+            has_optimization_config=True, with_batch=True
+        )
+        for trial in exp.trials.values():
+            trial.mark_running(no_runner_required=True).mark_completed()
+        metrics_dict = not_none(exp.optimization_config).metrics
+        objective_thresholds = [
+            ObjectiveThreshold(
+                metric=metrics_dict[f"branin_{letter}"],
+                bound=0.0,
+                relative=False,
+                op=ComparisonOp.GEQ,
+            )
+            for letter in "ab"
+        ]
+        # appease Pyre (this condition is True)
+        if isinstance(exp.optimization_config, MultiObjectiveOptimizationConfig):
+            exp.optimization_config = exp.optimization_config.clone_with_args(
+                objective_thresholds=objective_thresholds,
+            )
+
+        exp.attach_data(
+            get_branin_data_multi_objective(
+                trial_indices=exp.trials.keys(), num_objectives=2
+            ),
+        )
+        modelbridge = TorchModelBridge(
+            experiment=exp,
+            search_space=exp.search_space,
+            data=exp.fetch_data(),
+            model=MultiObjectiveBotorchModel(),
+            transforms=[],
+        )
+        observation_features = [
+            ObservationFeatures(parameters={"x1": 0.0, "x2": 1.0}),
+            ObservationFeatures(parameters={"x1": 1.0, "x2": 0.0}),
+        ]
+
+        with self.assertWarns(
+            Warning,
+            msg="FYI: The default behavior of `get_pareto_frontier_and_configs` when "
+            "`transform_outcomes_and_configs` is not specified has changed. Previously,"
+            " the default was `transform_outcomes_and_configs=True`; now this argument "
+            "is deprecated and behavior is as if "
+            "`transform_outcomes_and_configs=False`. You did not specify "
+            "`transform_outcomes_and_configs`, so this warning requires no action.",
+        ):
+            res = get_pareto_frontier_and_configs(
+                modelbridge=modelbridge,
+                observation_features=observation_features,
+            )
+            self.assertEqual(len(res), 4)
+
+        with self.assertRaises(UnsupportedError):
+            get_pareto_frontier_and_configs(
+                modelbridge=modelbridge,
+                observation_features=observation_features,
+                transform_outcomes_and_configs=True,
+            )
+
+        with self.assertWarns(
+            DeprecationWarning,
+            msg="You passed `transform_outcomes_and_configs=False`. Specifying "
+            "`transform_outcomes_and_configs` at all is deprecated because `False` is "
+            "now the only allowed behavior. In the future, this will become an error.",
+        ):
+            res = get_pareto_frontier_and_configs(
+                modelbridge=modelbridge,
+                observation_features=observation_features,
+                transform_outcomes_and_configs=False,
+            )
+            self.assertEqual(len(res), 4)
+
+        with self.assertWarns(
+            Warning,
+            msg="You provided `observation_data` when `use_model_predictions` is True; "
+            "`observation_data` will not be used.",
+        ):
+            res = get_pareto_frontier_and_configs(
+                modelbridge,
+                observation_features=observation_features,
+                use_model_predictions=True,
+                observation_data=[],
+            )
+            self.assertEqual(len(res), 4)
+
+        with self.assertRaises(ValueError):
+            get_pareto_frontier_and_configs(
+                modelbridge, observation_features=[], use_model_predictions=False
+            )
+
     @patch(
         # Mocking `BraninMetric` as not available while running, so it will
         # be grabbed from cache during `fetch_data`.
@@ -292,31 +384,28 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
             with patch(
                 PARETO_FRONTIER_EVALUATOR_PATH, wraps=pareto_frontier_evaluator
             ) as wrapped_frontier_evaluator:
-                # pyre-fixme[16]: Optional type has no attribute `frontier_evaluator`.
-                # pyre-fixme[16]: `TorchModel` has no attribute `frontier_evaluator`.
-                modelbridge.model.frontier_evaluator = wrapped_frontier_evaluator
                 hv = observed_hypervolume(
                     modelbridge=modelbridge, objective_thresholds=objective_thresholds
                 )
-                expected_hv = 20 if num_objectives == 2 else 60  # 5 * 4 (* 3)
-                wrapped_frontier_evaluator.assert_called_once()
+            expected_hv = 20 if num_objectives == 2 else 60  # 5 * 4 (* 3)
+            wrapped_frontier_evaluator.assert_called_once()
+            self.assertEqual(expected_hv, hv)
+            if num_objectives == 3:
+                # Test selected_metrics
+                hv = observed_hypervolume(
+                    modelbridge=modelbridge,
+                    objective_thresholds=objective_thresholds,
+                    selected_metrics=["branin_a", "branin_c"],
+                )
+                expected_hv = 15  # (5 - 0) * (5 - 2)
                 self.assertEqual(expected_hv, hv)
-                if num_objectives == 3:
-                    # Test selected_metrics
+                # test that non-objective outcome raises value error
+                with self.assertRaises(ValueError):
                     hv = observed_hypervolume(
                         modelbridge=modelbridge,
                         objective_thresholds=objective_thresholds,
-                        selected_metrics=["branin_a", "branin_c"],
+                        selected_metrics=["tracking"],
                     )
-                    expected_hv = 15  # (5 - 0) * (5 - 2)
-                    self.assertEqual(expected_hv, hv)
-                    # test that non-objective outcome raises value error
-                    with self.assertRaises(ValueError):
-                        hv = observed_hypervolume(
-                            modelbridge=modelbridge,
-                            objective_thresholds=objective_thresholds,
-                            selected_metrics=["tracking"],
-                        )
 
             with self.assertRaises(ValueError):
                 predicted_hypervolume(
