@@ -1,22 +1,27 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, TYPE_CHECKING
 
 from ax.core.multi_type_experiment import MultiTypeExperiment
-from ax.core.observation import Observation, ObservationData, ObservationFeatures
+from ax.core.observation import Observation, ObservationData
 from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig
 from ax.modelbridge.transforms.base import Transform
+from ax.models.types import TConfig
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.typeutils import not_none
 
+if TYPE_CHECKING:
+    # import as module to make sphinx-autodoc-typehints happy
+    from ax import modelbridge as modelbridge_module  # noqa F401  # pragma: no cover
+
 
 class ConvertMetricNames(Transform):
-    """Convert all metric names to canonical name as specified on a multi_type_experiment.
+    """Convert all metric names to canonical name as specified on a
+    multi_type_experiment.
 
     For example, a multi-type experiment may have an offline simulator which attempts to
     approximate observations from some online system. We want to map the offline
@@ -32,11 +37,12 @@ class ConvertMetricNames(Transform):
 
     def __init__(
         self,
-        search_space: Optional[SearchSpace],
-        observation_features: List[ObservationFeatures],
-        observation_data: List[ObservationData],
+        search_space: Optional[SearchSpace] = None,
+        observations: Optional[List[Observation]] = None,
+        modelbridge: Optional["modelbridge_module.base.ModelBridge"] = None,
         config: Optional[TConfig] = None,
     ) -> None:
+        assert observations is not None, "ConvertMetricNames requires observations"
         if config is None:
             raise ValueError("Config cannot be none.")
 
@@ -59,8 +65,8 @@ class ConvertMetricNames(Transform):
         if self.trial_index_to_type is None:
             raise ValueError("Config must contain trial_index_to_type")
 
-        for obsf in observation_features:
-            if obsf.trial_index not in self.trial_index_to_type:
+        for obs in observations:
+            if obs.features.trial_index not in self.trial_index_to_type:
                 raise ValueError("trial_index_to_type does not include all trials")
 
         # For each trial type, give a map from transformed name back to original
@@ -68,6 +74,7 @@ class ConvertMetricNames(Transform):
         self.reverse_metric_name_map: Dict[str, Dict[str, str]] = {}
 
         # For most practical cases we want to skip the untransform
+        # pyre-fixme[4]: Attribute must be annotated.
         self.perform_untransform = config.get("perform_untransform", False)
 
         for orig_name, trans_name in self.metric_name_map.items():
@@ -77,13 +84,10 @@ class ConvertMetricNames(Transform):
             else:
                 self.reverse_metric_name_map[trial_type] = {trans_name: orig_name}
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `observation_data` expected.
-    @copy_doc(Transform.transform_observation_data)
-    def transform_observation_data(
+    @copy_doc(Transform._transform_observation_data)
+    def _transform_observation_data(
         self,
         observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
     ) -> List[ObservationData]:
         for obsd in observation_data:
             for i in range(len(obsd.metric_names)):
@@ -91,28 +95,25 @@ class ConvertMetricNames(Transform):
                     obsd.metric_names[i] = self.metric_name_map[obsd.metric_names[i]]
         return observation_data
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `observation_data` expected.
-    @copy_doc(Transform.untransform_observation_data)
-    def untransform_observation_data(
+    @copy_doc(Transform.untransform_observations)
+    def untransform_observations(
         self,
-        observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
-    ) -> List[ObservationData]:
+        observations: List[Observation],
+    ) -> List[Observation]:
         if not self.perform_untransform:
-            return observation_data
-        for i, obsd in enumerate(observation_data):
-            trial_index = int(not_none(observation_features[i].trial_index))
+            return observations
+        for obs in observations:
+            trial_index = int(not_none(obs.features.trial_index))
             trial_type = self.trial_index_to_type[trial_index]
             reverse_map = self.reverse_metric_name_map.get(trial_type)
 
             if not reverse_map:
                 continue
 
-            for j in range(len(obsd.metric_names)):
-                if obsd.metric_names[j] in reverse_map:
-                    obsd.metric_names[j] = reverse_map[obsd.metric_names[j]]
-        return observation_data
+            for j in range(len(obs.data.metric_names)):
+                if obs.data.metric_names[j] in reverse_map:
+                    obs.data.metric_names[j] = reverse_map[obs.data.metric_names[j]]
+        return observations
 
 
 def tconfig_from_mt_experiment(experiment: MultiTypeExperiment) -> TConfig:
@@ -137,22 +138,12 @@ def convert_mt_observations(
     observations: List[Observation], experiment: MultiTypeExperiment
 ) -> List[Observation]:
     """Apply ConvertMetricNames transform to observations for a MT experiment."""
-    observation_data = [o.data for o in observations]
-    observation_features = [o.features for o in observations]
     transform = ConvertMetricNames(
         search_space=None,
-        observation_data=observation_data,
-        observation_features=observation_features,
+        observations=observations,
         config=tconfig_from_mt_experiment(experiment),
     )
-    transformed_observations = transform.transform_observation_data(
-        observation_data=observation_data, observation_features=observation_features
+    transformed_observations = transform.transform_observations(
+        observations=observations
     )
-    return [
-        Observation(
-            features=obs.features,
-            data=transformed_observations[i],
-            arm_name=obs.arm_name,
-        )
-        for i, obs in enumerate(observations)
-    ]
+    return transformed_observations
