@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -11,23 +11,26 @@ import torch
 from ax.core.search_space import SearchSpaceDigest
 from ax.models.torch.alebo import (
     ALEBO,
+    alebo_acqf_optimizer,
     ALEBOGP,
     ALEBOKernel,
-    alebo_acqf_optimizer,
     ei_or_nei,
     extract_map_statedict,
     get_batch_model,
     get_fitted_model,
     get_map_model,
 )
+from ax.models.torch_base import TorchOptConfig
 from ax.utils.common.testutils import TestCase
+from ax.utils.testing.mock import fast_botorch_optimize
 from botorch.acquisition.analytic import ExpectedImprovement
 from botorch.acquisition.monte_carlo import qNoisyExpectedImprovement
 from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.utils.datasets import FixedNoiseDataset
 
 
 class ALEBOTest(TestCase):
-    def testALEBOKernel(self):
+    def testALEBOKernel(self) -> None:
         B = torch.tensor(
             [[1.0, 2.0, 3.0, 4.0, 5.0], [2.0, 3.0, 4.0, 5.0, 6.0]], dtype=torch.double
         )
@@ -55,7 +58,8 @@ class ALEBOTest(TestCase):
         )
         self.assertTrue(torch.equal(K, Ktrue))
 
-    def testALEBOGP(self):
+    @fast_botorch_optimize
+    def testALEBOGP(self) -> None:
         # First non-batch
         B = torch.tensor(
             [[1.0, 2.0, 3.0, 4.0, 5.0], [2.0, 3.0, 4.0, 5.0, 6.0]], dtype=torch.double
@@ -85,7 +89,7 @@ class ALEBOTest(TestCase):
 
         # Batch
         Uvec_b = m.covar_module.base_kernel.Uvec.repeat(5, 1)
-        mean_b = m.mean_module.constant.repeat(5, 1)
+        mean_b = m.mean_module.constant.repeat(5)
         output_scale_b = m.covar_module.raw_outputscale.repeat(5)
         m_b = get_batch_model(
             B=B,
@@ -128,7 +132,7 @@ class ALEBOTest(TestCase):
             {
                 "covar_module.base_kernel.Uvec",
                 "covar_module.raw_outputscale",
-                "mean_module.constant",
+                "mean_module.raw_constant",
                 "covar_module.raw_outputscale_constraint.lower_bound",
                 "covar_module.raw_outputscale_constraint.upper_bound",
             },
@@ -147,7 +151,7 @@ class ALEBOTest(TestCase):
                 {
                     "covar_module.base_kernel.Uvec",
                     "covar_module.raw_outputscale",
-                    "mean_module.constant",
+                    "mean_module.raw_constant",
                     "covar_module.raw_outputscale_constraint.lower_bound",
                     "covar_module.raw_outputscale_constraint.upper_bound",
                 },
@@ -156,7 +160,7 @@ class ALEBOTest(TestCase):
                 map_sds[i]["covar_module.base_kernel.Uvec"].shape, torch.Size([3])
             )
 
-    def testAcq(self):
+    def testAcq(self) -> None:
         B = torch.tensor(
             [[1.0, 2.0, 3.0, 4.0, 5.0], [2.0, 3.0, 4.0, 5.0, 6.0]], dtype=torch.double
         )
@@ -177,6 +181,7 @@ class ALEBOTest(TestCase):
             noiseless=True,
         )
         self.assertIsInstance(acq, ExpectedImprovement)
+        # pyre-fixme[29]: `Union[BoundMethod[typing.Callable(torch._C._TensorBase.ite...
         self.assertEqual(acq.best_f.item(), 3.0)
 
         objective_weights = torch.tensor([-1.0], dtype=torch.double)
@@ -189,6 +194,7 @@ class ALEBOTest(TestCase):
             q=1,
             noiseless=True,
         )
+        # pyre-fixme[29]: `Union[BoundMethod[typing.Callable(torch._C._TensorBase.ite...
         self.assertEqual(acq.best_f.item(), 1.0)
         with mock.patch(
             "ax.models.torch.alebo.optimize_acqf",
@@ -197,8 +203,11 @@ class ALEBOTest(TestCase):
         ) as optim_mock:
             alebo_acqf_optimizer(
                 acq_function=acq,
+                # pyre-fixme[6]: For 2nd param expected `Tensor` but got `None`.
                 bounds=None,
                 n=1,
+                # pyre-fixme[6]: For 4th param expected `Optional[List[Tuple[Tensor,
+                #  Tensor, float]]]` but got `float`.
                 inequality_constraints=5.0,
                 fixed_features=None,
                 rounding_func=None,
@@ -229,8 +238,11 @@ class ALEBOTest(TestCase):
         ) as optim_mock:
             alebo_acqf_optimizer(
                 acq_function=acq,
+                # pyre-fixme[6]: For 2nd param expected `Tensor` but got `None`.
                 bounds=None,
                 n=2,
+                # pyre-fixme[6]: For 4th param expected `Optional[List[Tuple[Tensor,
+                #  Tensor, float]]]` but got `float`.
                 inequality_constraints=5.0,
                 fixed_features=None,
                 rounding_func=None,
@@ -251,10 +263,19 @@ class ALEBOTest(TestCase):
         Z = (B @ torch.pinverse(B) @ X[:, 0, :].t()).t()
         self.assertTrue(torch.allclose(Z, X[:, 0, :]))
 
-    def testALEBO(self):
+    @fast_botorch_optimize
+    def testALEBO(self) -> None:
         B = torch.tensor(
             [[1.0, 2.0, 3.0, 4.0, 5.0], [2.0, 3.0, 4.0, 5.0, 6.0]], dtype=torch.double
         )
+        m = ALEBO(B=B, laplace_nsamp=5, fit_restarts=1)
+        self.assertTrue(torch.equal(B, m.B))
+        self.assertEqual(m.laplace_nsamp, 5)
+        self.assertEqual(m.fit_restarts, 1)
+        self.assertEqual(m.refit_on_update, True)
+        self.assertEqual(m.refit_on_cv, False)
+        self.assertEqual(m.warm_start_refitting, False)
+
         train_X = torch.tensor(
             [
                 [0.0, 0.0, 0.0, 0.0, 0.0],
@@ -265,25 +286,18 @@ class ALEBOTest(TestCase):
         )
         train_Y = torch.tensor([[1.0], [2.0], [3.0]], dtype=torch.double)
         train_Yvar = 0.1 * torch.ones(3, 1, dtype=torch.double)
-
-        m = ALEBO(B=B, laplace_nsamp=5, fit_restarts=1)
-        self.assertTrue(torch.equal(B, m.B))
-        self.assertEqual(m.laplace_nsamp, 5)
-        self.assertEqual(m.fit_restarts, 1)
-        self.assertEqual(m.refit_on_update, True)
-        self.assertEqual(m.refit_on_cv, False)
-        self.assertEqual(m.warm_start_refitting, False)
+        dataset = FixedNoiseDataset(X=train_X, Y=train_Y, Yvar=train_Yvar)
 
         # Test fit
         m.fit(
-            Xs=[train_X, train_X],
-            Ys=[train_Y, train_Y],
-            Yvars=[train_Yvar, train_Yvar],
+            datasets=[dataset, dataset],
+            metric_names=["y1", "y2"],
             search_space_digest=SearchSpaceDigest(
                 feature_names=[],
+                # pyre-fixme[6]: For 2nd param expected `List[Tuple[Union[float,
+                #  int], Union[float, int]]]` but got `List[Tuple[int, int]]`.
                 bounds=[(-1, 1)] * 5,
             ),
-            metric_names=[],
         )
         self.assertIsInstance(m.model, ModelListGP)
         self.assertTrue(torch.allclose(m.Xs[0], (B @ train_X.t()).t()))
@@ -295,8 +309,18 @@ class ALEBOTest(TestCase):
 
         # Test best point
         objective_weights = torch.tensor([1.0, 0.0], dtype=torch.double)
+        search_space_digest = SearchSpaceDigest(
+            feature_names=[],
+            # pyre-fixme[6]: For 2nd param expected `List[Tuple[Union[float, int],
+            #  Union[float, int]]]` but got `List[Tuple[int, int]]`.
+            bounds=[(-1, 1)] * 5,
+        )
+        torch_opt_config = TorchOptConfig(objective_weights=objective_weights)
         with self.assertRaises(NotImplementedError):
-            m.best_point(bounds=[(-1, 1)] * 5, objective_weights=objective_weights)
+            m.best_point(
+                search_space_digest=search_space_digest,
+                torch_opt_config=torch_opt_config,
+            )
 
         # Test gen
         # With clipping
@@ -305,30 +329,31 @@ class ALEBOTest(TestCase):
             autospec=True,
             return_value=(m.Xs[0], torch.tensor([])),
         ):
-            Xopt, _, _, _ = m.gen(
+            gen_results = m.gen(
                 n=1,
-                bounds=[(-1, 1)] * 5,
-                objective_weights=torch.tensor([1.0, 0.0], dtype=torch.double),
+                search_space_digest=search_space_digest,
+                torch_opt_config=torch_opt_config,
             )
 
-        self.assertFalse(torch.allclose(Xopt, train_X))
-        self.assertTrue(Xopt.min() >= -1)
-        self.assertTrue(Xopt.max() <= 1)
+        self.assertFalse(torch.allclose(gen_results.points, train_X))
+        self.assertTrue(gen_results.points.min() >= -1)
+        self.assertTrue(gen_results.points.max() <= 1)
         # Without
         with mock.patch(
             "ax.models.torch.alebo.optimize_acqf",
             autospec=True,
             return_value=(torch.ones(1, 2, dtype=torch.double), torch.tensor([])),
         ):
-            Xopt, _, _, _ = m.gen(
+            gen_results = m.gen(
                 n=1,
-                bounds=[(-1, 1)] * 5,
-                objective_weights=torch.tensor([1.0, 0.0], dtype=torch.double),
+                search_space_digest=search_space_digest,
+                torch_opt_config=torch_opt_config,
             )
 
         self.assertTrue(
             torch.allclose(
-                Xopt, torch.tensor([[-0.2, -0.1, 0.0, 0.1, 0.2]], dtype=torch.double)
+                gen_results.points,
+                torch.tensor([[-0.2, -0.1, 0.0, 0.1, 0.2]], dtype=torch.double),
             )
         )
 
@@ -341,21 +366,14 @@ class ALEBOTest(TestCase):
             ],
             dtype=torch.double,
         )
-        m.update(
-            Xs=[train_X, train_X2],
-            Ys=[train_Y, train_Y],
-            Yvars=[train_Yvar, train_Yvar],
-        )
+        dataset2 = FixedNoiseDataset(X=train_X2, Y=train_Y, Yvar=train_Yvar)
+        m.update(datasets=[dataset, dataset2])
         self.assertTrue(torch.allclose(m.Xs[0], (B @ train_X.t()).t()))
         self.assertTrue(torch.allclose(m.Xs[1], (B @ train_X2.t()).t()))
         m.refit_on_update = False
-        m.update(
-            Xs=[train_X, train_X2],
-            Ys=[train_Y, train_Y],
-            Yvars=[train_Yvar, train_Yvar],
-        )
+        m.update(datasets=[dataset, dataset2])
 
-        # Test get_and_fit with single meric
+        # Test get_and_fit with single metric
         gp = m.get_and_fit_model(
             Xs=[(B @ train_X.t()).t()], Ys=[train_Y], Yvars=[train_Yvar]
         )
@@ -363,18 +381,14 @@ class ALEBOTest(TestCase):
 
         # Test cross_validate
         f, cov = m.cross_validate(
-            Xs_train=[train_X],
-            Ys_train=[train_Y],
-            Yvars_train=[train_Yvar],
+            datasets=[dataset],
             X_test=train_X2,
         )
         self.assertEqual(f.shape, torch.Size([3, 1]))
         self.assertEqual(cov.shape, torch.Size([3, 1, 1]))
         m.refit_on_cv = True
         f, cov = m.cross_validate(
-            Xs_train=[train_X],
-            Ys_train=[train_Y],
-            Yvars_train=[train_Yvar],
+            datasets=[dataset],
             X_test=train_X2,
         )
         self.assertEqual(f.shape, torch.Size([3, 1]))
