@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -8,11 +8,14 @@ from unittest import mock
 
 import torch
 from ax.models.torch.botorch_defaults import (
+    _get_acquisition_func,
     _get_model,
     get_and_fit_model,
     get_warping_transform,
 )
 from ax.utils.common.testutils import TestCase
+from ax.utils.testing.mock import fast_botorch_optimize
+from botorch.acquisition.penalized import PenalizedMCObjective
 from botorch.models import FixedNoiseGP, SingleTaskGP
 from botorch.models.gp_regression_fidelity import SingleTaskMultiFidelityGP
 from botorch.models.multitask import FixedNoiseMultiTaskGP, MultiTaskGP
@@ -23,10 +26,10 @@ from gpytorch.priors.prior import Prior
 
 
 class BotorchDefaultsTest(TestCase):
-    def test_get_model(self):
-        x = torch.zeros(2, 2)
-        y = torch.zeros(2, 1)
-        var = torch.zeros(2, 1)
+    def test_get_model(self) -> None:
+        x = torch.rand(2, 2)
+        y = torch.rand(2, 1)
+        var = torch.rand(2, 1)
         partial_var = torch.tensor([0, float("nan")]).unsqueeze(-1)
         unknown_var = torch.tensor([float("nan"), float("nan")]).unsqueeze(-1)
         model = _get_model(x, y, unknown_var, None)
@@ -56,31 +59,65 @@ class BotorchDefaultsTest(TestCase):
                 "eta": 0.6,
             }
         }
+        # pyre-fixme[6]: For 5th param expected `Optional[List[int]]` but got
+        #  `Dict[str, Union[Type[LKJCovariancePrior], float, GammaPrior]]`.
+        # pyre-fixme[6]: For 5th param expected `bool` but got `Dict[str,
+        #  Union[Type[LKJCovariancePrior], float, GammaPrior]]`.
         model = _get_model(X=x, Y=y, Yvar=partial_var.clone(), task_feature=1, **kwargs)
         self.assertIsInstance(
-            model.task_covar_module.IndexKernelPrior, LKJCovariancePrior
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior,
+            LKJCovariancePrior,
         )
         self.assertEqual(
-            model.task_covar_module.IndexKernelPrior.sd_prior.concentration, 2.0
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior.sd_prior.concentration,
+            2.0,
         )
+        # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no attribute
+        #  `IndexKernelPrior`.
         self.assertEqual(model.task_covar_module.IndexKernelPrior.sd_prior.rate, 0.44)
         self.assertEqual(
-            model.task_covar_module.IndexKernelPrior.correlation_prior.eta, 0.6
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior.correlation_prior.eta,
+            0.6,
         )
 
         kwargs2 = {"prior": {"type": LKJCovariancePrior}}
         model = _get_model(
-            X=x, Y=y, Yvar=partial_var.clone(), task_feature=1, **kwargs2
+            X=x,
+            Y=y,
+            Yvar=partial_var.clone(),
+            task_feature=1,
+            # pyre-fixme[6]: For 5th param expected `Optional[List[int]]` but got
+            #  `Dict[str, Type[LKJCovariancePrior]]`.
+            # pyre-fixme[6]: For 5th param expected `bool` but got `Dict[str,
+            #  Type[LKJCovariancePrior]]`.
+            **kwargs2,
         )
         self.assertIsInstance(
-            model.task_covar_module.IndexKernelPrior, LKJCovariancePrior
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior,
+            LKJCovariancePrior,
         )
         self.assertEqual(
-            model.task_covar_module.IndexKernelPrior.sd_prior.concentration, 1.0
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior.sd_prior.concentration,
+            1.0,
         )
+        # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no attribute
+        #  `IndexKernelPrior`.
         self.assertEqual(model.task_covar_module.IndexKernelPrior.sd_prior.rate, 0.15)
         self.assertEqual(
-            model.task_covar_module.IndexKernelPrior.correlation_prior.eta, 0.5
+            # pyre-fixme[16]: Item `Tensor` of `Union[Tensor, Module]` has no
+            #  attribute `IndexKernelPrior`.
+            model.task_covar_module.IndexKernelPrior.correlation_prior.eta,
+            0.5,
         )
         kwargs3 = {
             "prior": {
@@ -90,15 +127,26 @@ class BotorchDefaultsTest(TestCase):
             }
         }
         with self.assertRaises(ValueError):
+            # pyre-fixme[6]: For 5th param expected `Optional[List[int]]` but got
+            #  `Dict[str, Union[Type[LKJCovariancePrior], GammaPrior, str]]`.
+            # pyre-fixme[6]: For 5th param expected `bool` but got `Dict[str,
+            #  Union[Type[LKJCovariancePrior], GammaPrior, str]]`.
             _get_model(X=x, Y=y, Yvar=partial_var.clone(), task_feature=1, **kwargs3)
 
         kwargs5 = {
             "prior": {"type": Prior, "sd_prior": GammaPrior(2.0, 0.44), "eta": 0.5}
         }
         with self.assertRaises(NotImplementedError):
+            # pyre-fixme[6]: For 5th param expected `Optional[List[int]]` but got
+            #  `Dict[str, Union[Type[Prior], float, GammaPrior]]`.
+            # pyre-fixme[6]: For 5th param expected `bool` but got `Dict[str,
+            #  Union[Type[Prior], float, GammaPrior]]`.
             _get_model(X=x, Y=y, Yvar=partial_var.clone(), task_feature=1, **kwargs5)
 
     @mock.patch("ax.models.torch.botorch_defaults._get_model", wraps=_get_model)
+    @fast_botorch_optimize
+    # pyre-fixme[3]: Return type must be annotated.
+    # pyre-fixme[2]: Parameter must be annotated.
     def test_task_feature(self, get_model_mock):
         x = [torch.zeros(2, 2)]
         y = [torch.zeros(2, 1)]
@@ -155,7 +203,42 @@ class BotorchDefaultsTest(TestCase):
                 refit_model=False,
             )
 
-    def test_get_warping_transform(self):
+    def test_get_acquisition_func(self) -> None:
+        x = torch.zeros(2, 2)
+        y = torch.zeros(2, 1)
+        unknown_var = torch.tensor([float("nan"), float("nan")]).unsqueeze(-1)
+        model = _get_model(x, y, unknown_var, None)
+        objective_weights = torch.tensor([1.0])
+        outcome_constraints = (
+            torch.tensor([[0.0, 1.0]]),
+            torch.tensor([[5.0]]),
+        )
+        X_observed = torch.zeros(2, 2)
+        with self.assertRaises(ValueError) as cm:
+            _get_acquisition_func(
+                model=model,
+                acquisition_function_name="qNEI",
+                objective_weights=objective_weights,
+                outcome_constraints=outcome_constraints,
+                X_observed=X_observed,
+                constrained_mc_objective=None,
+            )
+        self.assertEqual(
+            "constrained_mc_objective cannot be set to None "
+            "when applying outcome constraints.",
+            str(cm.exception),
+        )
+        with self.assertRaises(RuntimeError):
+            _get_acquisition_func(
+                model=model,
+                acquisition_function_name="qNEI",
+                objective_weights=objective_weights,
+                mc_objective=PenalizedMCObjective,
+                outcome_constraints=outcome_constraints,
+                X_observed=X_observed,
+            )
+
+    def test_get_warping_transform(self) -> None:
         warp_tf = get_warping_transform(d=4)
         self.assertIsInstance(warp_tf, Warp)
         self.assertEqual(warp_tf.indices.tolist(), list(range(4)))
