@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -12,17 +12,17 @@ from ax.core.search_space import SearchSpaceDigest
 from ax.models.model_utils import (
     best_observed_point,
     check_duplicate,
-    mk_discrete_choices,
     enumerate_discrete_combinations,
+    mk_discrete_choices,
 )
 from ax.utils.common.testutils import TestCase
 
 
 class ModelUtilsTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         pass
 
-    def testBestObservedPoint(self):
+    def testBestObservedPoint(self) -> None:
         model = MagicMock()
 
         X1 = np.array(list(product(np.arange(0.0, 10.0), np.arange(0.0, 10.0))))
@@ -140,14 +140,14 @@ class ModelUtilsTest(TestCase):
                 options={"method": "feasible_threshold"},
             )
 
-    def testCheckDuplicate(self):
+    def testCheckDuplicate(self) -> None:
         duplicate_point = np.array([0, 1])
         not_duplicate_point = np.array([9, 9])
         points = np.array([[0, 1], [0, 2], [0, 1]])
         self.assertTrue(check_duplicate(duplicate_point, points))
         self.assertFalse(check_duplicate(not_duplicate_point, points))
 
-    def testMkDiscreteChoices(self):
+    def testMkDiscreteChoices(self) -> None:
         ssd1 = SearchSpaceDigest(
             feature_names=["a", "b"],
             bounds=[(0, 1), (0, 2)],
@@ -168,11 +168,15 @@ class ModelUtilsTest(TestCase):
         dc2_ff = mk_discrete_choices(ssd2, fixed_features={1: 0})
         self.assertEqual(dc2_ff, {1: [0], 2: [3, 4]})
 
-    def testEnumerateDiscreteCombinations(self):
+    def testEnumerateDiscreteCombinations(self) -> None:
         dc1 = {1: [0, 1, 2]}
+        # pyre-fixme[6]: For 1st param expected `Dict[int, List[Union[float, int]]]`
+        #  but got `Dict[int, List[int]]`.
         dc1_enum = enumerate_discrete_combinations(dc1)
         self.assertEqual(dc1_enum, [{1: 0}, {1: 1}, {1: 2}])
         dc2 = {1: [0, 1, 2], 2: [3, 4]}
+        # pyre-fixme[6]: For 1st param expected `Dict[int, List[Union[float, int]]]`
+        #  but got `Dict[int, List[int]]`.
         dc2_enum = enumerate_discrete_combinations(dc2)
         self.assertEqual(
             dc2_enum,
