@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -20,7 +20,7 @@ from torch import Tensor
 
 
 class TorchUtilsTest(TestCase):
-    def test_is_noiseless(self):
+    def test_is_noiseless(self) -> None:
         x = torch.zeros(1, 1)
         y = torch.zeros(1, 1)
         se = torch.zeros(1, 1)
@@ -31,7 +31,7 @@ class TorchUtilsTest(TestCase):
         with self.assertRaises(ModelError):
             is_noiseless(ModelListGP())
 
-    def testNormalizeIndices(self):
+    def testNormalizeIndices(self) -> None:
         indices = [0, 2]
         nlzd_indices = normalize_indices(indices, 3)
         self.assertEqual(nlzd_indices, indices)
@@ -45,7 +45,7 @@ class TorchUtilsTest(TestCase):
         with self.assertRaises(ValueError):
             nlzd_indices = normalize_indices([-4], 3)
 
-    def testSubsetModel(self):
+    def testSubsetModel(self) -> None:
         x = torch.zeros(1, 1)
         y = torch.rand(1, 2)
         obj_t = torch.rand(2)
@@ -73,6 +73,7 @@ class TorchUtilsTest(TestCase):
         self.assertIsNone(obj_t_sub)
         self.assertIs(model_sub, model)  # check identity
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
+        self.assertTrue(torch.equal(subset_model_results.indices, torch.tensor([0, 1])))
         # test w/ outcome constraints, can subset
         obj_weights = torch.tensor([1.0, 0.0])
         ocs = (torch.tensor([[1.0, 0.0]]), torch.tensor([1.0]))
@@ -84,8 +85,10 @@ class TorchUtilsTest(TestCase):
         self.assertEqual(model_sub.num_outputs, 1)
         self.assertIsNone(obj_t_sub)
         self.assertTrue(torch.equal(obj_weights_sub, torch.tensor([1.0])))
+        # pyre-fixme[16]: Optional type has no attribute `__getitem__`.
         self.assertTrue(torch.equal(ocs_sub[0], torch.tensor([[1.0]])))
         self.assertTrue(torch.equal(ocs_sub[1], torch.tensor([1.0])))
+        self.assertTrue(torch.equal(subset_model_results.indices, torch.tensor([0])))
         # test w/ outcome constraints, cannot subset
         obj_weights = torch.tensor([1.0, 0.0])
         ocs = (torch.tensor([[0.0, 1.0]]), torch.tensor([1.0]))
@@ -98,6 +101,7 @@ class TorchUtilsTest(TestCase):
         self.assertIsNone(obj_t_sub)
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
         self.assertIs(ocs_sub, ocs)  # check identity
+        self.assertTrue(torch.equal(subset_model_results.indices, torch.tensor([0, 1])))
         # test w/ objective thresholds, cannot subset
         obj_weights = torch.tensor([1.0, 0.0])
         ocs = (torch.tensor([[0.0, 1.0]]), torch.tensor([1.0]))
@@ -122,6 +126,7 @@ class TorchUtilsTest(TestCase):
         self.assertTrue(torch.equal(subset_model_results.indices, torch.tensor([0])))
         self.assertEqual(model_sub.num_outputs, 1)
         self.assertTrue(torch.equal(obj_weights_sub, torch.tensor([1.0])))
+        # pyre-fixme[6]: For 1st param expected `Tensor` but got `Optional[Tensor]`.
         self.assertTrue(torch.equal(obj_t_sub, obj_t[:1]))
         self.assertTrue(torch.equal(ocs_sub[0], torch.tensor([[1.0]])))
         self.assertTrue(torch.equal(ocs_sub[1], torch.tensor([1.0])))
@@ -136,12 +141,13 @@ class TorchUtilsTest(TestCase):
         self.assertIsNone(ocs_sub)
         self.assertIs(model_sub, model)  # check identity
         self.assertIs(obj_weights_sub, obj_weights)  # check identity
+        self.assertTrue(torch.equal(subset_model_results.indices, torch.tensor([0, 1])))
         # test error on size inconsistency
         obj_weights = torch.ones(3)
         with self.assertRaises(RuntimeError):
             subset_model(model, obj_weights)
 
-    def testGenerateSobolPoints(self):
+    def testGenerateSobolPoints(self) -> None:
         bounds = [(0.0, 1.0) for _ in range(3)]
         linear_constraints = (
             torch.tensor([[1, -1, 0]], dtype=torch.double),
@@ -161,7 +167,7 @@ class TorchUtilsTest(TestCase):
         self.assertEqual(len(gen_sobol), 100)
         self.assertIsInstance(gen_sobol, Tensor)
 
-    def testTensorCallableToArrayCallable(self):
+    def testTensorCallableToArrayCallable(self) -> None:
         def tensor_func(x: Tensor) -> Tensor:
             return np.exp(x)
 
