@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -7,12 +7,15 @@
 from __future__ import annotations
 
 from copy import deepcopy
+
+from logging import Logger
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
 import torch
 from ax.core.search_space import SearchSpaceDigest
-from ax.core.types import TCandidateMetadata, TConfig, TGenMetadata
+from ax.core.types import TCandidateMetadata
+from ax.exceptions.core import DataRequiredError
 from ax.models.torch.botorch_defaults import (
     get_and_fit_model,
     get_NEI,
@@ -20,25 +23,29 @@ from ax.models.torch.botorch_defaults import (
     scipy_optimizer,
 )
 from ax.models.torch.utils import (
+    _datasets_to_legacy_inputs,
     _get_X_pending_and_observed,
     _to_inequality_constraints,
     normalize_indices,
     predict_from_model,
     subset_model,
 )
-from ax.models.torch_base import TorchModel
+from ax.models.torch_base import TorchGenResults, TorchModel, TorchOptConfig
+from ax.models.types import TConfig
 from ax.utils.common.constants import Keys
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
-from ax.utils.common.typeutils import checked_cast
+from ax.utils.common.typeutils import checked_cast, not_none
 from botorch.acquisition.acquisition import AcquisitionFunction
 from botorch.models.model import Model
 from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.utils.datasets import SupervisedDataset
 from torch import Tensor
 
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
+# pyre-fixme[33]: Aliased annotation cannot contain `Any`.
 TModelConstructor = Callable[
     [
         List[Tensor],
@@ -53,6 +60,7 @@ TModelConstructor = Callable[
     Model,
 ]
 TModelPredictor = Callable[[Model, Tensor], Tuple[Tensor, Tensor]]
+# pyre-fixme[33]: Aliased annotation cannot contain `Any`.
 TAcqfConstructor = Callable[
     [
         Model,
@@ -64,6 +72,7 @@ TAcqfConstructor = Callable[
     ],
     AcquisitionFunction,
 ]
+# pyre-fixme[33]: Aliased annotation cannot contain `Any`.
 TOptimizer = Callable[
     [
         AcquisitionFunction,
@@ -227,6 +236,7 @@ class BotorchModel(TorchModel):
     Xs: List[Tensor]
     Ys: List[Tensor]
     Yvars: List[Tensor]
+    model: Optional[Model]
 
     def __init__(
         self,
@@ -253,6 +263,7 @@ class BotorchModel(TorchModel):
         self.acqf_constructor = acqf_constructor
         self.acqf_optimizer = acqf_optimizer
         self.best_point_recommender = best_point_recommender
+        # pyre-fixme[4]: Attribute must be annotated.
         self._kwargs = kwargs
         self.refit_on_cv = refit_on_cv
         self.refit_on_update = refit_on_update
@@ -272,29 +283,28 @@ class BotorchModel(TorchModel):
     @copy_doc(TorchModel.fit)
     def fit(
         self,
-        Xs: List[Tensor],
-        Ys: List[Tensor],
-        Yvars: List[Tensor],
-        search_space_digest: SearchSpaceDigest,
+        datasets: List[SupervisedDataset],
         metric_names: List[str],
+        search_space_digest: SearchSpaceDigest,
         candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
     ) -> None:
-        self.dtype = Xs[0].dtype
-        self.device = Xs[0].device
-        self.Xs = Xs
-        self.Ys = Ys
-        self.Yvars = Yvars
+        if len(datasets) == 0:
+            raise DataRequiredError("BotorchModel.fit requires non-empty data sets.")
+        Xs, Ys, Yvars = _datasets_to_legacy_inputs(datasets=datasets)
+        self.metric_names = metric_names
+        self.Xs, self.Ys, self.Yvars = Xs, Ys, Yvars
+        self.dtype = self.Xs[0].dtype
+        self.device = self.Xs[0].device
         self.task_features = normalize_indices(
-            search_space_digest.task_features, d=Xs[0].size(-1)
+            search_space_digest.task_features, d=self.Xs[0].size(-1)
         )
         self.fidelity_features = normalize_indices(
-            search_space_digest.fidelity_features, d=Xs[0].size(-1)
+            search_space_digest.fidelity_features, d=self.Xs[0].size(-1)
         )
-        self.metric_names = metric_names
         self.model = self.model_constructor(  # pyre-ignore [28]
-            Xs=Xs,
-            Ys=Ys,
-            Yvars=Yvars,
+            Xs=self.Xs,
+            Ys=self.Ys,
+            Yvars=self.Yvars,
             task_features=self.task_features,
             fidelity_features=self.fidelity_features,
             metric_names=self.metric_names,
@@ -311,58 +321,59 @@ class BotorchModel(TorchModel):
     def gen(
         self,
         n: int,
-        bounds: List[Tuple[float, float]],
-        objective_weights: Tensor,
-        outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
-        linear_constraints: Optional[Tuple[Tensor, Tensor]] = None,
-        fixed_features: Optional[Dict[int, float]] = None,
-        pending_observations: Optional[List[Tensor]] = None,
-        model_gen_options: Optional[TConfig] = None,
-        rounding_func: Optional[Callable[[Tensor], Tensor]] = None,
-        target_fidelities: Optional[Dict[int, float]] = None,
-    ) -> Tuple[Tensor, Tensor, TGenMetadata, Optional[List[TCandidateMetadata]]]:
-        options = model_gen_options or {}
+        search_space_digest: SearchSpaceDigest,
+        torch_opt_config: TorchOptConfig,
+    ) -> TorchGenResults:
+        options = torch_opt_config.model_gen_options or {}
         acf_options = options.get(Keys.ACQF_KWARGS, {})
         optimizer_options = options.get(Keys.OPTIMIZER_KWARGS, {})
 
-        if target_fidelities:
+        if search_space_digest.target_fidelities:
             raise NotImplementedError(
                 "target_fidelities not implemented for base BotorchModel"
             )
         X_pending, X_observed = _get_X_pending_and_observed(
             Xs=self.Xs,
-            pending_observations=pending_observations,
-            objective_weights=objective_weights,
-            outcome_constraints=outcome_constraints,
-            bounds=bounds,
-            linear_constraints=linear_constraints,
-            fixed_features=fixed_features,
+            objective_weights=torch_opt_config.objective_weights,
+            bounds=search_space_digest.bounds,
+            pending_observations=torch_opt_config.pending_observations,
+            outcome_constraints=torch_opt_config.outcome_constraints,
+            linear_constraints=torch_opt_config.linear_constraints,
+            fixed_features=torch_opt_config.fixed_features,
         )
-
         model = self.model
-
         # subset model only to the outcomes we need for the optimization	357
         if options.get(Keys.SUBSET_MODEL, True):
             subset_model_results = subset_model(
                 model=model,  # pyre-ignore [6]
-                objective_weights=objective_weights,
-                outcome_constraints=outcome_constraints,
+                objective_weights=torch_opt_config.objective_weights,
+                outcome_constraints=torch_opt_config.outcome_constraints,
             )
             model = subset_model_results.model
             objective_weights = subset_model_results.objective_weights
             outcome_constraints = subset_model_results.outcome_constraints
+        else:
+            objective_weights = torch_opt_config.objective_weights
+            outcome_constraints = torch_opt_config.outcome_constraints
 
-        bounds_ = torch.tensor(bounds, dtype=self.dtype, device=self.device)
+        bounds_ = torch.tensor(
+            search_space_digest.bounds, dtype=self.dtype, device=self.device
+        )
         bounds_ = bounds_.transpose(0, 1)
 
-        botorch_rounding_func = get_rounding_func(rounding_func)
-
-        # The following logic is to work around the limitation of PyTorch's Sobol
-        # sampler to <1111 dimensions.
-        # TODO: Remove once https://github.com/pytorch/pytorch/issues/41489 is resolved.
+        botorch_rounding_func = get_rounding_func(torch_opt_config.rounding_func)
 
         from botorch.exceptions.errors import UnsupportedError
 
+        # pyre-fixme[53]: Captured variable `X_observed` is not annotated.
+        # pyre-fixme[53]: Captured variable `X_pending` is not annotated.
+        # pyre-fixme[53]: Captured variable `acf_options` is not annotated.
+        # pyre-fixme[53]: Captured variable `botorch_rounding_func` is not annotated.
+        # pyre-fixme[53]: Captured variable `bounds_` is not annotated.
+        # pyre-fixme[53]: Captured variable `model` is not annotated.
+        # pyre-fixme[53]: Captured variable `objective_weights` is not annotated.
+        # pyre-fixme[53]: Captured variable `optimizer_options` is not annotated.
+        # pyre-fixme[53]: Captured variable `outcome_constraints` is not annotated.
         def make_and_optimize_acqf(override_qmc: bool = False) -> Tuple[Tensor, Tensor]:
             add_kwargs = {"qmc": False} if override_qmc else {}
             acquisition_function = self.acqf_constructor(  # pyre-ignore: [28]
@@ -383,9 +394,9 @@ class BotorchModel(TorchModel):
                 bounds=bounds_,
                 n=n,
                 inequality_constraints=_to_inequality_constraints(
-                    linear_constraints=linear_constraints
+                    linear_constraints=torch_opt_config.linear_constraints
                 ),
-                fixed_features=fixed_features,
+                fixed_features=torch_opt_config.fixed_features,
                 rounding_func=botorch_rounding_func,
                 **optimizer_options,
             )
@@ -393,8 +404,8 @@ class BotorchModel(TorchModel):
 
         try:
             candidates, expected_acquisition_value = make_and_optimize_acqf()
-        except UnsupportedError as e:
-            if "SobolQMCSampler only supports dimensions q * o <= 1111" in str(e):
+        except UnsupportedError as e:  # untested
+            if "SobolQMCSampler only supports dimensions" in str(e):
                 # dimension too large for Sobol, let's use IID
                 candidates, expected_acquisition_value = make_and_optimize_acqf(
                     override_qmc=True
@@ -402,42 +413,43 @@ class BotorchModel(TorchModel):
             else:
                 raise e
 
-        return (
-            candidates.detach().cpu(),
-            torch.ones(n, dtype=self.dtype),
-            {"expected_acquisition_value": expected_acquisition_value.tolist()},
-            None,
+        gen_metadata = {}
+        if expected_acquisition_value.numel() > 0:
+            gen_metadata[
+                "expected_acquisition_value"
+            ] = expected_acquisition_value.tolist()
+
+        return TorchGenResults(
+            points=candidates.detach().cpu(),
+            weights=torch.ones(n, dtype=self.dtype),
+            gen_metadata=gen_metadata,
         )
 
     @copy_doc(TorchModel.best_point)
     def best_point(
         self,
-        bounds: List[Tuple[float, float]],
-        objective_weights: Tensor,
-        outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
-        linear_constraints: Optional[Tuple[Tensor, Tensor]] = None,
-        fixed_features: Optional[Dict[int, float]] = None,
-        model_gen_options: Optional[TConfig] = None,
-        target_fidelities: Optional[Dict[int, float]] = None,
+        search_space_digest: SearchSpaceDigest,
+        torch_opt_config: TorchOptConfig,
     ) -> Optional[Tensor]:
-
+        if torch_opt_config.is_moo:
+            raise NotImplementedError(
+                "Best observed point is incompatible with MOO problems."
+            )
         return self.best_point_recommender(  # pyre-ignore [28]
             model=self,
-            bounds=bounds,
-            objective_weights=objective_weights,
-            outcome_constraints=outcome_constraints,
-            linear_constraints=linear_constraints,
-            fixed_features=fixed_features,
-            model_gen_options=model_gen_options,
-            target_fidelities=target_fidelities,
+            bounds=search_space_digest.bounds,
+            objective_weights=torch_opt_config.objective_weights,
+            outcome_constraints=torch_opt_config.outcome_constraints,
+            linear_constraints=torch_opt_config.linear_constraints,
+            fixed_features=torch_opt_config.fixed_features,
+            model_gen_options=torch_opt_config.model_gen_options,
+            target_fidelities=search_space_digest.target_fidelities,
         )
 
     @copy_doc(TorchModel.cross_validate)
-    def cross_validate(  # pyre-ignore[14]: Some `TorchModel.cross_validate` kwargs
-        self,  # are not needed here and therefore we just use `**kwargs` catchall.
-        Xs_train: List[Tensor],
-        Ys_train: List[Tensor],
-        Yvars_train: List[Tensor],
+    def cross_validate(  # pyre-ignore [14]: `search_space_digest` arg not needed here
+        self,
+        datasets: List[SupervisedDataset],
         X_test: Tensor,
         **kwargs: Any,
     ) -> Tuple[Tensor, Tensor]:
@@ -446,11 +458,12 @@ class BotorchModel(TorchModel):
         if self.refit_on_cv:
             state_dict = None
         else:
-            state_dict = deepcopy(self.model.state_dict())  # pyre-ignore: [16]
+            state_dict = deepcopy(self.model.state_dict())
+        Xs, Ys, Yvars = _datasets_to_legacy_inputs(datasets=datasets)
         model = self.model_constructor(  # pyre-ignore: [28]
-            Xs=Xs_train,
-            Ys=Ys_train,
-            Yvars=Yvars_train,
+            Xs=Xs,
+            Ys=Ys,
+            Yvars=Yvars,
             task_features=self.task_features,
             state_dict=state_dict,
             fidelity_features=self.fidelity_features,
@@ -463,23 +476,22 @@ class BotorchModel(TorchModel):
         return self.model_predictor(model=model, X=X_test)  # pyre-ignore: [28]
 
     @copy_doc(TorchModel.update)
-    def update(  # pyre-ignore[14]: Some `TorchModel.update` kwargs are not
-        self,  # needed here and therefore we just use `**kwargs` catchall.
-        Xs: List[Tensor],
-        Ys: List[Tensor],
-        Yvars: List[Tensor],
+    def update(  # pyre-ignore [14]: `search_space_digest` arg not needed here
+        self,
+        datasets: List[SupervisedDataset],
         candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
         **kwargs: Any,
     ) -> None:
         if self.model is None:
             raise RuntimeError("Cannot update model that has not been fitted")
+        Xs, Ys, Yvars = _datasets_to_legacy_inputs(datasets=datasets)
         self.Xs = Xs
         self.Ys = Ys
         self.Yvars = Yvars
         if self.refit_on_update and not self.warm_start_refitting:
             state_dict = None  # pragma: no cover
         else:
-            state_dict = deepcopy(self.model.state_dict())  # pyre-ignore: [16]
+            state_dict = deepcopy(not_none(self.model).state_dict())
         self.model = self.model_constructor(  # pyre-ignore: [28]
             Xs=self.Xs,
             Ys=self.Ys,
@@ -500,7 +512,7 @@ class BotorchModel(TorchModel):
                 "Cannot calculate feature_importances without a fitted model"
             )
         elif isinstance(self.model, ModelListGP):
-            models = self.model.models  # pyre-ignore: [16]
+            models = self.model.models
         else:
             models = [self.model]
         lengthscales = []
@@ -510,6 +522,8 @@ class BotorchModel(TorchModel):
                 ls = ls.unsqueeze(0)
             lengthscales.append(ls)
         lengthscales = torch.cat(lengthscales, dim=0)
+        # pyre-fixme[16]: `float` has no attribute `detach`.
+        # pyre-fixme[58]: `/` is not supported for operand types `int` and `Tensor`.
         return (1 / lengthscales).detach().cpu().numpy()
 
 
