@@ -1,44 +1,56 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 from dataclasses import dataclass
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, cast
+
+from logging import Logger
+from typing import Any, Callable, cast, Dict, List, Optional, Tuple, Type
 
 import numpy as np
 import torch
-from ax.core.types import TConfig
+from ax.exceptions.core import UnsupportedError
 from ax.exceptions.model import ModelError
 from ax.models.model_utils import filter_constraints_and_fixed_features, get_observed
 from ax.models.random.sobol import SobolGenerator
+from ax.models.types import TConfig
 from ax.utils.common.constants import Keys
 from ax.utils.common.logger import get_logger
 from botorch.acquisition.acquisition import AcquisitionFunction
 from botorch.acquisition.analytic import PosteriorMean
 from botorch.acquisition.fixed_feature import FixedFeatureAcquisitionFunction
 from botorch.acquisition.monte_carlo import qSimpleRegret
-from botorch.acquisition.multi_objective.objective import WeightedMCMultiOutputObjective
+from botorch.acquisition.multi_objective.multi_output_risk_measures import (
+    MARS,
+    MultiOutputRiskMeasureMCObjective,
+)
+from botorch.acquisition.multi_objective.objective import (
+    IdentityMCMultiOutputObjective,
+    WeightedMCMultiOutputObjective,
+)
 from botorch.acquisition.objective import (
-    AcquisitionObjective,
     ConstrainedMCObjective,
+    IdentityMCObjective,
     LinearMCObjective,
     MCAcquisitionObjective,
-    ScalarizedObjective,
+    PosteriorTransform,
+    ScalarizedPosteriorTransform,
 )
+from botorch.acquisition.risk_measures import RiskMeasureMCObjective
 from botorch.acquisition.utils import get_infeasible_cost
-from botorch.exceptions.errors import UnsupportedError
 from botorch.models import ModelListGP, SingleTaskGP
 from botorch.models.model import Model
+from botorch.posteriors.fully_bayesian import FullyBayesianPosterior
 from botorch.sampling.samplers import IIDNormalSampler, SobolQMCNormalSampler
 from botorch.utils.constraints import get_outcome_constraint_transforms
+from botorch.utils.datasets import FixedNoiseDataset, SupervisedDataset
 from botorch.utils.objective import get_objective_weights_transform
 from botorch.utils.sampling import sample_hypersphere, sample_simplex
 from torch import Tensor
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 NOISELESS_MODELS = {SingleTaskGP}
@@ -128,12 +140,12 @@ def _get_X_pending_and_observed(
 
     Args:
         Xs: The input tensors of a model.
-        pending_observations:  A list of m (k_i x d) feature tensors X
-            for m outcomes and k_i pending observations for outcome i.
-            (Only used if n > 1).
         objective_weights: The objective is to maximize a weighted sum of
             the columns of f(x). These are the weights.
         bounds: A list of (lower, upper) tuples for each column of X.
+        pending_observations:  A list of m (k_i x d) feature tensors X
+            for m outcomes and k_i pending observations for outcome i.
+            (Only used if n > 1).
         outcome_constraints: A tuple of (A, b). For k outcome constraints
             and m outputs at f(x), A is (k x m) and b is (k x 1) such that
             A f(x) <= b. (Not used by single task models)
@@ -266,7 +278,7 @@ def subset_model(
     if outcome_constraints is not None:
         A, _ = outcome_constraints
         nonzero = nonzero | torch.any(A != 0, dim=0)
-    idcs_t = torch.arange(nonzero.size(0))[nonzero]
+    idcs_t = torch.arange(nonzero.size(0), device=objective_weights.device)[nonzero]
     idcs = idcs_t.tolist()
     if len(idcs) == model.num_outputs:
         # if we use all model outputs, just return the inputs
@@ -275,7 +287,10 @@ def subset_model(
             objective_weights=objective_weights,
             outcome_constraints=outcome_constraints,
             objective_thresholds=objective_thresholds,
-            indices=idcs_t,
+            indices=torch.arange(
+                model.num_outputs,
+                device=objective_weights.device,
+            ),
         )
     elif len(idcs) > model.num_outputs:
         raise RuntimeError(
@@ -291,7 +306,10 @@ def subset_model(
         if objective_thresholds is not None:
             objective_thresholds = objective_thresholds[nonzero]
     except NotImplementedError:
-        pass
+        idcs_t = torch.arange(
+            model.num_outputs,
+            device=objective_weights.device,
+        )
     return SubsetModelData(
         model=model,
         objective_weights=objective_weights,
@@ -322,32 +340,83 @@ def tensor_callable_to_array_callable(
     tensor_func: Callable[[Tensor], Tensor], device: torch.device
 ) -> Callable[[np.ndarray], np.ndarray]:
     """transfer a tensor callable to an array callable"""
-    # TODO: move this reuseable function and its  equivalent reverse functions
-    # to some utils files
+
     def array_func(x: np.ndarray) -> np.ndarray:
         return tensor_func(torch.from_numpy(x).to(device)).detach().numpy()
 
     return array_func
 
 
-def get_botorch_objective(
+def _get_weighted_mo_objective(
+    objective_weights: Tensor,
+) -> WeightedMCMultiOutputObjective:
+    """Constructs the `WeightedMCMultiOutputObjective` for the given
+    objective weights.
+    """
+    nonzero_idcs = torch.nonzero(objective_weights).view(-1)
+    objective_weights = objective_weights[nonzero_idcs]
+    return WeightedMCMultiOutputObjective(
+        weights=objective_weights, outcomes=nonzero_idcs.tolist()
+    )
+
+
+def _get_risk_measure(
+    model: Model,
+    objective_weights: Tensor,
+    risk_measure: RiskMeasureMCObjective,
+    outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
+    X_observed: Optional[Tensor] = None,
+) -> RiskMeasureMCObjective:
+    r"""Processes the risk measure for `get_botorch_objective_and_transform`.
+    See the docstring of `get_botorch_objective_and_transform` for the arguments.
+    """
+    if outcome_constraints is not None:
+        # TODO[T131759270]: Handle the constraints via feasibility weighting.
+        # See `FeasibilityWeightedMCMultiOutputObjective`.
+        raise NotImplementedError(
+            "Outcome constraints are not supported with risk measures."
+        )
+    # Isinstance doesn't work since it covers subclasses as well.
+    if risk_measure.preprocessing_function.__class__ not in (
+        IdentityMCObjective,
+        IdentityMCMultiOutputObjective,
+    ) or hasattr(risk_measure.preprocessing_function, "outcomes"):
+        raise UnsupportedError(
+            "User supplied preprocessing functions for the risk measures are not "
+            "supported. We construct a new one based on `objective_weights` instead."
+        )
+    if isinstance(risk_measure, MultiOutputRiskMeasureMCObjective):
+        risk_measure.preprocessing_function = _get_weighted_mo_objective(
+            objective_weights=objective_weights
+        )
+        if isinstance(risk_measure, MARS):
+            risk_measure.chebyshev_weights = sample_simplex(
+                len(objective_weights.nonzero())
+            ).squeeze()
+            if X_observed is None:
+                raise UnsupportedError("X_observed is required when using MARS.")
+            risk_measure.set_baseline_Y(model=model, X_baseline=X_observed)
+    else:
+        risk_measure.preprocessing_function = LinearMCObjective(
+            weights=objective_weights
+        )
+    return risk_measure
+
+
+def get_botorch_objective_and_transform(
     model: Model,
     objective_weights: Tensor,
-    use_scalarized_objective: bool = True,
     outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
     objective_thresholds: Optional[Tensor] = None,
     X_observed: Optional[Tensor] = None,
-) -> AcquisitionObjective:
+    risk_measure: Optional[RiskMeasureMCObjective] = None,
+) -> Tuple[Optional[MCAcquisitionObjective], Optional[PosteriorTransform]]:
     """Constructs a BoTorch `AcquisitionObjective` object.
 
     Args:
         model: A BoTorch Model
         objective_weights: The objective is to maximize a weighted sum of
             the columns of f(x). These are the weights.
-        use_scalarized_objective: A boolean parameter that defaults to True,
-            specifying whether ScalarizedObjective should be used.
-            NOTE: when using outcome_constraints, use_scalarized_objective
-            will be ignored.
         outcome_constraints: A tuple of (A, b). For k outcome constraints
             and m outputs at f(x), A is (k x m) and b is (k x 1) such that
             A f(x) <= b. (Not used by single task models)
@@ -356,41 +425,47 @@ def get_botorch_objective(
             dominate the objective_thresholds contribute nothing to hypervolume.
         X_observed: Observed points that are feasible and appear in the
             objective or the constraints. None if there are no such points.
+        risk_measure: An optional risk measure for robust optimization.
 
     Returns:
-        A BoTorch `AcquisitionObjective` object. It will be one of:
-        `ScalarizedObjective`, `LinearMCOObjective`, `ConstrainedMCObjective`.
+        A two-tuple containing (optionally) an `MCAcquisitionObjective` and
+        (optionally) a `PosteriorTransform`.
     """
+    if risk_measure is not None:
+        risk_measure = _get_risk_measure(
+            model=model,
+            objective_weights=objective_weights,
+            risk_measure=risk_measure,
+            outcome_constraints=outcome_constraints,
+            X_observed=X_observed,
+        )
+        return risk_measure, None
+
     if objective_thresholds is not None:
-        nonzero_idcs = torch.nonzero(objective_weights).view(-1)
-        objective_weights = objective_weights[nonzero_idcs]
-        return WeightedMCMultiOutputObjective(
-            weights=objective_weights, outcomes=nonzero_idcs.tolist()
-        )
-    if X_observed is None:
-        raise UnsupportedError(
-            "X_observed is required to construct a BoTorch Objective."
-        )
+        # We are doing multi-objective optimization.
+        return _get_weighted_mo_objective(objective_weights=objective_weights), None
     if outcome_constraints:
-        if use_scalarized_objective:
-            logger.warning(
-                "Currently cannot use ScalarizedObjective when there are outcome "
-                "constraints. Ignoring (default) kwarg `use_scalarized_objective`"
-                "= True. Creating ConstrainedMCObjective."
+        if X_observed is None:
+            raise UnsupportedError(
+                "X_observed is required to construct a constrained BoTorch objective."
             )
-        obj_tf = get_objective_weights_transform(objective_weights)
+        # If there are outcome constraints, we use MC Acquisition functions.
+        obj_tf: Callable[
+            [Tensor, Optional[Tensor]], Tensor
+        ] = get_objective_weights_transform(objective_weights)
 
         def objective(samples: Tensor, X: Optional[Tensor] = None) -> Tensor:
-            return obj_tf(samples)
+            return obj_tf(samples, X)
 
         con_tfs = get_outcome_constraint_transforms(outcome_constraints)
         inf_cost = get_infeasible_cost(X=X_observed, model=model, objective=obj_tf)
-        return ConstrainedMCObjective(
+        objective = ConstrainedMCObjective(
             objective=objective, constraints=con_tfs or [], infeasible_cost=inf_cost
         )
-    elif use_scalarized_objective:
-        return ScalarizedObjective(weights=objective_weights)
-    return LinearMCObjective(weights=objective_weights)
+        return objective, None
+    # Case of linear weights - use ScalarizedPosteriorTransform
+    transform = ScalarizedPosteriorTransform(weights=objective_weights)
+    return None, transform
 
 
 def get_out_of_sample_best_point_acqf(
@@ -405,6 +480,7 @@ def get_out_of_sample_best_point_acqf(
     outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
     seed_inner: Optional[int] = None,
     qmc: bool = True,
+    risk_measure: Optional[RiskMeasureMCObjective] = None,
     **kwargs: Any,
 ) -> Tuple[AcquisitionFunction, Optional[List[int]]]:
     """Picks an appropriate acquisition function to find the best
@@ -450,20 +526,26 @@ def get_out_of_sample_best_point_acqf(
         mc_samples=mc_samples,
         qmc=qmc,
         seed_inner=seed_inner,
+        risk_measure=risk_measure,
     )
-    objective = get_botorch_objective(
+    objective, posterior_transform = get_botorch_objective_and_transform(
         model=model,
         objective_weights=objective_weights,
         outcome_constraints=outcome_constraints,
         X_observed=X_observed,
+        risk_measure=risk_measure,
     )
-    if not isinstance(objective, (ScalarizedObjective, MCAcquisitionObjective)):
-        raise UnsupportedError(
-            f"Unknown objective type: {objective.__class__}"  # pragma: nocover
-        )
-    else:
-        # pyre-ignore[28]: All acq. functions here expect `objective` kwarg.
-        acqf = acqf_class(model=model, objective=objective, **acqf_options)
+
+    if objective is not None:
+        if not isinstance(objective, MCAcquisitionObjective):
+            raise UnsupportedError(
+                f"Unknown objective type: {objective.__class__}"  # pragma: nocover
+            )
+        acqf_options = {"objective": objective, **acqf_options}
+    if posterior_transform is not None:
+        acqf_options = {"posterior_transform": posterior_transform, **acqf_options}
+
+    acqf = acqf_class(model=model, **acqf_options)  # pyre-ignore [45]
 
     if fixed_features:
         acqf = FixedFeatureAcquisitionFunction(
@@ -485,8 +567,9 @@ def pick_best_out_of_sample_point_acqf_class(
     mc_samples: int = 512,
     qmc: bool = True,
     seed_inner: Optional[int] = None,
+    risk_measure: Optional[RiskMeasureMCObjective] = None,
 ) -> Tuple[Type[AcquisitionFunction], Dict[str, Any]]:
-    if outcome_constraints is None:
+    if outcome_constraints is None and risk_measure is None:
         acqf_class = PosteriorMean
         acqf_options = {}
     else:
@@ -502,6 +585,10 @@ def pick_best_out_of_sample_point_acqf_class(
 def predict_from_model(model: Model, X: Tensor) -> Tuple[Tensor, Tensor]:
     r"""Predicts outcomes given a model and input tensor.
 
+    For a `FullyBayesianPosterior` we currently use a Gaussian approximation where we
+    compute the mean and variance of the Gaussian mixture. This should ideally be
+    changed to compute quantiles instead when Ax supports non-Gaussian distributions.
+
     Args:
         model: A botorch Model.
         X: A `n x d` tensor of input parameters.
@@ -511,11 +598,15 @@ def predict_from_model(model: Model, X: Tensor) -> Tuple[Tensor, Tensor]:
         Tensor: The predicted posterior covariance as a `n x o x o`-dim tensor.
     """
     with torch.no_grad():
+        # TODO: Allow Posterior to (optionally) return the full covariance matrix
         posterior = model.posterior(X)
-    mean = posterior.mean.cpu().detach()
-    # TODO: Allow Posterior to (optionally) return the full covariance matrix
-    variance = posterior.variance.cpu().detach().clamp_min(0)  # pyre-ignore
-    cov = torch.diag_embed(variance)
+        if isinstance(posterior, FullyBayesianPosterior):
+            mean = posterior.mixture_mean.cpu().detach()
+            var = posterior.mixture_variance.cpu().detach().clamp_min(0)
+        else:
+            mean = posterior.mean.cpu().detach()
+            var = posterior.variance.cpu().detach().clamp_min(0)
+    cov = torch.diag_embed(var)
     return mean, cov
 
 
@@ -552,3 +643,20 @@ def randomize_objective_weights(
     # pyre-fixme[61]: `random_weights` may not be initialized here.
     objective_weights = torch.mul(objective_weights, random_weights)
     return objective_weights
+
+
+def _datasets_to_legacy_inputs(
+    datasets: List[SupervisedDataset],
+) -> Tuple[List[Tensor], List[Tensor], List[Tensor]]:
+    """Convert a dictionary of dataset containers to legacy X, Y, Yvar inputs"""
+    Xs, Ys, Yvars = [], [], []
+    for dataset in datasets:
+        if not isinstance(dataset, SupervisedDataset):
+            raise UnsupportedError("Legacy setup only supports `SupervisedDataset`s")
+        Xs.append(dataset.X())
+        Ys.append(dataset.Y())
+        if isinstance(dataset, FixedNoiseDataset):
+            Yvars.append(dataset.Yvar())
+        else:
+            Yvars.append(torch.full_like(Ys[-1], float("nan")))
+    return Xs, Ys, Yvars
