@@ -1,11 +1,13 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 import math
 from collections import Counter
+
+from logging import Logger
 from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
 
 import numpy as np
@@ -14,13 +16,13 @@ from ax.core.observation import Observation, ObservationFeatures
 from ax.core.parameter import ChoiceParameter, FixedParameter, RangeParameter
 from ax.core.types import TParameterization
 from ax.modelbridge.base import ModelBridge
+from ax.modelbridge.prediction_utils import predict_at_point
 from ax.modelbridge.transforms.ivw import IVW
 from ax.plot.base import DECIMALS, PlotData, PlotInSampleArm, PlotOutOfSampleArm, Z
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import not_none
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 # Typing alias
 RawData = List[Dict[str, Union[str, float]]]
@@ -111,7 +113,22 @@ def arm_name_to_tuple(arm_name: str) -> Union[Tuple[int, int], Tuple[int]]:
     return (0,)
 
 
-def resize_subtitles(figure: Dict[str, Any], size: int):
+def arm_name_to_sort_key(arm_name: str) -> Tuple[str, int, int]:
+    """Parses arm name into tuple suitable for reverse sorting by key
+
+    Example:
+        arm_names = ["0_0", "1_10", "1_2", "10_0", "control"]
+        sorted(arm_names, key=arm_name_to_sort_key, reverse=True)
+        ["control", "0_0", "1_2", "1_10", "10_0"]
+    """
+    try:
+        trial_index, arm_index = arm_name.split("_")
+        return ("", -int(trial_index), -int(arm_index))
+    except (ValueError, IndexError):
+        return (arm_name, 0, 0)
+
+
+def resize_subtitles(figure: Dict[str, Any], size: int) -> Dict[str, Any]:
     for ant in figure["layout"]["annotations"]:
         ant["font"].update(size=size)
     return figure
@@ -158,8 +175,17 @@ def _get_in_sample_arms(
         - Map from arm name to parameters
     """
     observations = model.get_training_data()
+    training_in_design = model.training_in_design
     if data_selector is not None:
         observations = [obs for obs in observations if data_selector(obs)]
+        training_in_design = [
+            model.training_in_design[i]
+            for i, obs in enumerate(observations)
+            if data_selector(obs)
+        ]
+    trial_selector = None
+    if fixed_features is not None:
+        trial_selector = fixed_features.trial_index
     # Calculate raw data
     raw_data = []
     arm_name_to_parameters = {}
@@ -178,8 +204,9 @@ def _get_in_sample_arms(
 
     # Check that we have one ObservationFeatures per arm name since we
     # key by arm name and the model is not Multi-task.
-    # If "TrialAsTask" is present, one of the arms is also chosen.
-    if ("TrialAsTask" not in model.transforms.keys()) and (
+    # If "TrialAsTask" is present, one of the arms is chosen based on the selected
+    # trial index in the fixed_features.
+    if ("TrialAsTask" not in model.transforms.keys() or trial_selector is None) and (
         len(arm_name_to_parameters) != len(observations)
     ):
         logger.error(
@@ -189,8 +216,8 @@ def _get_in_sample_arms(
 
     # Merge multiple measurements within each Observation with IVW to get
     # un-modeled prediction
-    t = IVW(None, [], [])
-    obs_data = t.transform_observation_data([obs.data for obs in observations], [])
+    t = IVW(None, [])
+    observations = t.transform_observations(observations)
     # Start filling in plot data
     in_sample_plot: Dict[str, PlotInSampleArm] = {}
     for i, obs in enumerate(observations):
@@ -200,19 +227,24 @@ def _get_in_sample_arms(
         # Extract raw measurement
         obs_y = {}  # Observed metric means.
         obs_se = {}  # Observed metric standard errors.
-        # Use the IVW data, not obs.data
-        for j, metric_name in enumerate(obs_data[i].metric_names):
+        for j, metric_name in enumerate(obs.data.metric_names):
             if metric_name in metric_names:
-                obs_y[metric_name] = obs_data[i].means[j]
-                obs_se[metric_name] = np.sqrt(obs_data[i].covariance[j, j])
-        # Make a prediction.
-        features = obs.features
-        if fixed_features is not None:
-            features.update_features(fixed_features)
-        if model.training_in_design[i]:
-            pred_y, pred_se = _predict_at_point(model, features, metric_names)
+                obs_y[metric_name] = obs.data.means[j]
+                obs_se[metric_name] = np.sqrt(obs.data.covariance[j, j])
+        if training_in_design[i]:
+            # Update with the input fixed features
+            features = obs.features
+            if fixed_features is not None:
+                features.update_features(fixed_features)
+            # Make a prediction.
+            pred_y, pred_se = predict_at_point(model, features, metric_names)
+        elif (trial_selector is not None) and (
+            obs.features.trial_index != trial_selector
+        ):
+            # check whether the observation is from the right trial
+            # need to use raw data in the selected trial for out-of-design points
+            continue
         else:
-            # Use raw data for out-of-design points
             pred_y = obs_y
             pred_se = obs_se
         in_sample_plot[not_none(obs.arm_name)] = PlotInSampleArm(
@@ -227,34 +259,6 @@ def _get_in_sample_arms(
     return in_sample_plot, raw_data, arm_name_to_parameters
 
 
-def _predict_at_point(
-    model: ModelBridge, obsf: ObservationFeatures, metric_names: Set[str]
-) -> Tuple[Dict[str, float], Dict[str, float]]:
-    """Make a prediction at a point.
-
-    Returns mean and standard deviation in format expected by plotting.
-
-    Args:
-        model: ModelBridge
-        obsf: ObservationFeatures for which to predict
-        metric_names: Limit predictions to these metrics.
-
-    Returns:
-        A tuple containing
-
-        - Map from metric name to prediction.
-        - Map from metric name to standard error.
-    """
-    y_hat = {}
-    se_hat = {}
-    f_pred, cov_pred = model.predict([obsf])
-    for metric_name in f_pred:
-        if metric_name in metric_names:
-            y_hat[metric_name] = f_pred[metric_name][0]
-            se_hat[metric_name] = np.sqrt(cov_pred[metric_name][metric_name][0])
-    return y_hat, se_hat
-
-
 def _get_out_of_sample_arms(
     model: ModelBridge,
     generator_runs_dict: Dict[str, GeneratorRun],
@@ -286,7 +290,7 @@ def _get_out_of_sample_arms(
 
             # Make a prediction
             try:
-                pred_y, pred_se = _predict_at_point(model, obsf, metric_names)
+                pred_y, pred_se = predict_at_point(model, obsf, metric_names)
             except Exception:
                 # Check if it is an out-of-design arm.
                 if not model.model_space.check_membership(obsf.parameters):
@@ -355,7 +359,6 @@ def get_plot_data(
         metric_names=metrics_plot,
         fixed_features=fixed_features,
     )
-    # pyre-fixme[16]: `Optional` has no attribute `arm_name`.
     status_quo_name = None if model.status_quo is None else model.status_quo.arm_name
     plot_data = PlotData(
         metrics=list(metrics_plot),
@@ -418,7 +421,7 @@ def get_grid_for_parameter(parameter: RangeParameter, density: int) -> np.ndarra
         grid = np.linspace(
             np.log10(parameter.lower), np.log10(parameter.upper), density
         )
-        grid = 10 ** grid
+        grid = 10**grid
     else:
         grid = np.linspace(parameter.lower, parameter.upper, density)
     return grid
@@ -451,7 +454,6 @@ def get_fixed_values(
 
     # Check if status_quo is in design
     if model.status_quo is not None and model.model_space.check_membership(
-        # pyre-fixme[16]: `Optional` has no attribute `features`.
         model.status_quo.features.parameters
     ):
         setx = model.status_quo.features.parameters
@@ -482,7 +484,8 @@ def get_fixed_values(
 
 
 # Utility methods ported from JS
-def contour_config_to_trace(config):
+# pyre-fixme[2]: Parameter must be annotated.
+def contour_config_to_trace(config) -> List[Dict[str, Any]]:
     # Load from config
     arm_data = config["arm_data"]
     density = config["density"]
@@ -568,13 +571,28 @@ def contour_config_to_trace(config):
     sd_trace.update(CONTOUR_CONFIG)
 
     # get in-sample arms
-    arm_text = list(arm_data["in_sample"].keys())
+    arm_names = list(arm_data["in_sample"].keys())
     arm_x = [
-        arm_data["in_sample"][arm_name]["parameters"][xvar] for arm_name in arm_text
+        arm_data["in_sample"][arm_name]["parameters"][xvar] for arm_name in arm_names
     ]
     arm_y = [
-        arm_data["in_sample"][arm_name]["parameters"][yvar] for arm_name in arm_text
+        arm_data["in_sample"][arm_name]["parameters"][yvar] for arm_name in arm_names
     ]
+    arm_text = []
+    for arm_name in arm_names:
+        atext = f"Arm {arm_name}"
+        params = arm_data["in_sample"][arm_name]["parameters"]
+        ys = arm_data["in_sample"][arm_name]["y"]
+        ses = arm_data["in_sample"][arm_name]["se"]
+        for yname in ys.keys():
+            sem_str = f"{ses[yname]}" if ses[yname] is None else f"{ses[yname]:.6g}"
+            y_str = f"{ys[yname]}" if ys[yname] is None else f"{ys[yname]:.6g}"
+            atext += f"<br>{yname}: {y_str} (SEM: {sem_str})"
+        for pname in params.keys():
+            pval = params[pname]
+            pstr = f"{pval:.6g}" if isinstance(pval, float) else f"{pval}"
+            atext += f"<br>{pname}: {pstr}"
+        arm_text.append(atext)
 
     # configs for in-sample arms
     base_in_sample_arm_config = {
@@ -593,7 +611,12 @@ def contour_config_to_trace(config):
 
     sd_in_sample_arm_trace = {"showlegend": False, "xaxis": "x2", "yaxis": "y2"}
 
+    # pyre-fixme[6]: For 1st param expected `SupportsKeysAndGetItem[str, str]` but
+    #  got `Dict[str, Union[Dict[str, Union[float, str]], List[typing.Any], str]]`.
     f_in_sample_arm_trace.update(base_in_sample_arm_config)
+    # pyre-fixme[6]: For 1st param expected `SupportsKeysAndGetItem[str, Union[bool,
+    #  str]]` but got `Dict[str, Union[Dict[str, Union[float, str]], List[typing.Any],
+    #  str]]`.
     sd_in_sample_arm_trace.update(base_in_sample_arm_config)
 
     traces = [f_trace, sd_trace, f_in_sample_arm_trace, sd_in_sample_arm_trace]
@@ -662,13 +685,18 @@ def axis_range(grid: List[float], is_log: bool) -> List[float]:
 
 
 def relativize(m_t: float, sem_t: float, m_c: float, sem_c: float) -> List[float]:
-    r_hat = (m_t - m_c) / abs(m_c) - sem_c ** 2 * m_t / abs(m_c) ** 3
-    variance = (sem_t ** 2 + (m_t / m_c * sem_c) ** 2) / m_c ** 2
+    r_hat = (m_t - m_c) / abs(m_c) - sem_c**2 * m_t / abs(m_c) ** 3
+    variance = (sem_t**2 + (m_t / m_c * sem_c) ** 2) / m_c**2
     return [r_hat, math.sqrt(variance)]
 
 
 def relativize_data(
-    f: List[float], sd: List[float], rel: bool, arm_data: Dict[Any, Any], metric: str
+    f: List[float],
+    sd: List[float],
+    rel: bool,
+    # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
+    arm_data: Dict[Any, Any],
+    metric: str,
 ) -> List[List[float]]:
     # if relative, extract status quo & compute ratio
     f_final = [] if rel else f
@@ -722,19 +750,27 @@ def infer_is_relative(
 
 
 def slice_config_to_trace(
+    # pyre-fixme[2]: Parameter must be annotated.
     arm_data,
+    # pyre-fixme[2]: Parameter must be annotated.
     arm_name_to_parameters,
-    f,
+    f: List[float],
+    # pyre-fixme[2]: Parameter must be annotated.
     fit_data,
+    # pyre-fixme[2]: Parameter must be annotated.
     grid,
-    metric,
+    metric: str,
+    # pyre-fixme[2]: Parameter must be annotated.
     param,
-    rel,
+    rel: bool,
+    # pyre-fixme[2]: Parameter must be annotated.
     setx,
-    sd,
+    sd: List[float],
+    # pyre-fixme[2]: Parameter must be annotated.
     is_log,
+    # pyre-fixme[2]: Parameter must be annotated.
     visible,
-):
+) -> List[Dict[str, Any]]:
     # format data
     res = relativize_data(f, sd, rel, arm_data, metric)
     f_final = res[0]
@@ -768,7 +804,7 @@ def slice_config_to_trace(
 
     arm_res = relativize_data(arm_y, arm_sem, rel, arm_data, metric)
     arm_y_final = arm_res[0]
-    arm_sem_final = [x * 2 for x in arm_res[1]]
+    arm_sem_final = [x * 2 if x is not None else None for x in arm_res[1]]
 
     # create traces
     f_trace = {
@@ -875,3 +911,23 @@ def build_filter_trial(keep_trial_indices: List[int]) -> Callable[[Observation],
         return obs.features.trial_index in keep_trial_indices
 
     return trial_filter
+
+
+def compose_annotation(
+    caption: str, x: float = 0.0, y: float = -0.15
+) -> List[Dict[str, Any]]:
+    if not caption:
+        return []
+    return [
+        {
+            "showarrow": False,
+            "text": caption,
+            "x": x,
+            "xanchor": "left",
+            "xref": "paper",
+            "y": y,
+            "yanchor": "top",
+            "yref": "paper",
+            "align": "left",
+        },
+    ]
