@@ -1,10 +1,11 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 import math
+from typing import Tuple
 
 import pandas as pd
 import plotly.graph_objs as go
@@ -14,12 +15,13 @@ from ax.modelbridge.factory import get_empirical_bayes_thompson, get_thompson
 from ax.plot.base import AxPlotConfig, AxPlotTypes, PlotMetric, Z
 from ax.plot.helper import get_plot_data
 from ax.plot.scatter import _error_scatter_data
+from pandas.core.frame import DataFrame
 
 
 COLOR_SCALE = ["#ff3333", "#ff6666", "#ffffff", "#99ff99", "#33ff33"]
 
 
-def get_color(x: float, ci: float, rel: bool, reverse: bool):
+def get_color(x: float, ci: float, rel: bool, reverse: bool) -> str:
     """Determine the color of the table cell."""
     if not rel:
         # Color coding is meant to be relative to the status quo,
@@ -40,7 +42,7 @@ def table_view_plot(
     use_empirical_bayes: bool = True,
     only_data_frame: bool = False,
     arm_noun: str = "arm",
-):
+) -> Tuple[DataFrame]:
     """Table of means and confidence intervals.
 
     Table is of the form:
@@ -98,10 +100,6 @@ def table_view_plot(
     records_with_ci = []
     for metric_name in metric_names:
         arm_names, _, ys, ys_se = _error_scatter_data(
-            # pyre-fixme[6]: Expected
-            #  `List[typing.Union[ax.plot.base.PlotInSampleArm,
-            #  ax.plot.base.PlotOutOfSampleArm]]` for 1st param but got
-            #  `List[ax.plot.base.PlotInSampleArm]`.
             arms=list(plot_data.in_sample.values()),
             y_axis_var=PlotMetric(metric_name, pred=True, rel=rel),
             x_axis_var=None,
@@ -139,13 +137,13 @@ def table_view_plot(
             for records in [records_with_mean, records_with_ci]
         )
 
+    # pyre-fixme[3]: Return type must be annotated.
+    # pyre-fixme[2]: Parameter must be annotated.
     def transpose(m):
         return [[m[j][i] for j in range(len(m))] for i in range(len(m[0]))]
 
     records = [[name.replace(":", " : ") for name in metric_names]] + transpose(records)
     colors = [["#ffffff"] * len(metric_names)] + transpose(colors)
-    # pyre-fixme[58]: `+` is not supported for operand types `List[str]` and
-    #  `List[float]`.
     # pyre-fixme[61]: `arm_names` may not be initialized here.
     header = [f"<b>{x}</b>" for x in [f"{arm_noun}s"] + arm_names]
     # pyre-fixme[61]: `arm_names` may not be initialized here.
@@ -161,4 +159,5 @@ def table_view_plot(
         margin=go.layout.Margin(l=0, r=20, b=20, t=20, pad=4),  # noqa E741
     )
     fig = go.Figure(data=[trace], layout=layout)
+    # pyre-fixme[7]: Expected `Tuple[DataFrame]` but got `AxPlotConfig`.
     return AxPlotConfig(data=fig, plot_type=AxPlotTypes.GENERIC)
