@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -17,8 +17,8 @@ from ax.utils.common.testutils import TestCase
 from ax.utils.testing.core_stubs import (
     get_data,
     get_experiment,
-    get_search_space,
     get_experiment_with_data,
+    get_search_space,
 )
 from ax.utils.testing.modeling_stubs import get_observation
 
@@ -32,7 +32,11 @@ from ax.utils.testing.modeling_stubs import get_observation
     "ax.modelbridge.base.gen_arms", autospec=True, return_value=[Arm(parameters={})]
 )
 def get_modelbridge(
-    mock_gen_arms, mock_observations_from_data, status_quo_name: Optional[str] = None
+    # pyre-fixme[2]: Parameter must be annotated.
+    mock_gen_arms,
+    # pyre-fixme[2]: Parameter must be annotated.
+    mock_observations_from_data,
+    status_quo_name: Optional[str] = None,
 ) -> ModelBridge:
     exp = get_experiment()
     modelbridge = ModelBridge(
@@ -51,7 +55,7 @@ def get_modelbridge(
 
 
 class TileFittedTest(TestCase):
-    def testTileFitted(self):
+    def testTileFitted(self) -> None:
         model = get_modelbridge(status_quo_name=None)
 
         # Should throw if `status_quo_arm` is None and rel=True
@@ -111,11 +115,13 @@ class TileFittedTest(TestCase):
 
 
 class TileObservationsTest(TestCase):
-    def testTileObservations(self):
+    def testTileObservations(self) -> None:
         exp = get_experiment_with_data()
         exp.trials[0].run()
         exp.trials[0].mark_completed()
         exp.add_tracking_metric(Metric("ax_test_metric"))
+        # pyre-fixme[6]: For 1st param expected `List[Parameter]` but got
+        #  `dict_values[str, Parameter]`.
         exp.search_space = SearchSpace(parameters=exp.search_space.parameters.values())
         config = tile_observations(experiment=exp, arm_names=["0_1", "0_2"], rel=False)
 
