@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Iterable, Optional, Set
 
-from ax.core.base_trial import BaseTrial
+from ax.core.base_trial import BaseTrial, TrialStatus
 from ax.core.runner import Runner
 
 
@@ -16,7 +16,7 @@ class SyntheticRunner(Runner):
     Currently acts as a shell runner, only creating a name.
     """
 
-    def __init__(self, dummy_metadata: Optional[str] = None):
+    def __init__(self, dummy_metadata: Optional[str] = None) -> None:
         self.dummy_metadata = dummy_metadata
 
     def run(self, trial: BaseTrial) -> Dict[str, Any]:
@@ -29,6 +29,10 @@ class SyntheticRunner(Runner):
 
         # Add dummy metadata if needed for testing
         if self.dummy_metadata:
-            # pyre-fixme[6]: Expected `str` for 2nd param but got `Optional[str]`.
             metadata["dummy_metadata"] = self.dummy_metadata
         return metadata
+
+    def poll_trial_status(
+        self, trials: Iterable[BaseTrial]
+    ) -> Dict[TrialStatus, Set[int]]:
+        return {TrialStatus.COMPLETED: {t.index for t in trials}}
