@@ -17,6 +17,7 @@ from typing import (
     Iterable,
     List,
     Optional,
+    Sequence,
     Set,
     Tuple,
     Type,
@@ -244,7 +245,7 @@ class AxClient(WithDBSettingsBase, BestPointMixin, InstantiationBase):
     def create_experiment(
         self,
         parameters: List[
-            Dict[str, Union[TParamValue, List[TParamValue], Dict[str, List[str]]]],
+            Dict[str, Union[TParamValue, Sequence[TParamValue], Dict[str, List[str]]]]
         ],
         name: Optional[str] = None,
         description: Optional[str] = None,
@@ -434,6 +435,51 @@ class AxClient(WithDBSettingsBase, BestPointMixin, InstantiationBase):
                 "optimization config not set because it was missing objectives"
             )
 
+    def set_search_space(
+        self,
+        parameters: List[
+            Dict[str, Union[TParamValue, Sequence[TParamValue], Dict[str, List[str]]]]
+        ],
+        parameter_constraints: Optional[List[str]] = None,
+    ) -> None:
+        """Sets the search space on the experiment and saves.
+        This is expected to fail on base AxClient as experiment will have
+        immutable search space and optimization config set to True by default
+
+        Args:
+            parameters: List of dictionaries representing parameters in the
+                experiment search space.
+                Required elements in the dictionaries are:
+                1. "name" (name of parameter, string),
+                2. "type" (type of parameter: "range", "fixed", or "choice", string),
+                and one of the following:
+                3a. "bounds" for range parameters (list of two values, lower bound
+                first),
+                3b. "values" for choice parameters (list of values), or
+                3c. "value" for fixed parameters (single value).
+                Optional elements are:
+                1. "log_scale" (for float-valued range parameters, bool),
+                2. "value_type" (to specify type that values of this parameter should
+                take; expects "float", "int", "bool" or "str"),
+                3. "is_fidelity" (bool) and "target_value" (float) for fidelity
+                parameters,
+                4. "is_ordered" (bool) for choice parameters, and
+                5. "is_task" (bool) for task parameters.
+                6. "digits" (int) for float-valued range parameters.
+            parameter_constraints: List of string representation of parameter
+                constraints, such as "x3 >= x4" or "-x3 + 2*x4 - 3.5*x5 >= 2". For
+                the latter constraints, any number of arguments is accepted, and
+                acceptable operators are "<=" and ">=". Note that parameter
+                constraints may only be placed on range parameters, not choice
+                parameters or fixed parameters.
+        """
+        self.experiment.search_space = self.make_search_space(
+            parameters=parameters, parameter_constraints=parameter_constraints
+        )
+        self._save_experiment_to_db_if_possible(
+            experiment=self.experiment,
+        )
+
     @retry_on_exception(
         logger=logger,
         exception_types=(RuntimeError,),
@@ -773,7 +819,10 @@ class AxClient(WithDBSettingsBase, BestPointMixin, InstantiationBase):
         )
 
     def attach_trial(
-        self, parameters: TParameterization, ttl_seconds: Optional[int] = None
+        self,
+        parameters: TParameterization,
+        ttl_seconds: Optional[int] = None,
+        run_metadata: Optional[Dict[str, Any]] = None,
     ) -> Tuple[TParameterization, int]:
         """Attach a new trial with the given parameterization to the experiment.
 
@@ -810,6 +859,8 @@ class AxClient(WithDBSettingsBase, BestPointMixin, InstantiationBase):
             "Attached custom parameterization "
             f"{round_floats_for_logging(item=parameters)} as trial {trial.index}."
         )
+        if run_metadata is not None:
+            trial.update_run_metadata(metadata=run_metadata)
         self._save_or_update_trial_in_db_if_possible(
             experiment=self.experiment,
             trial=trial,
@@ -1405,7 +1456,8 @@ class AxClient(WithDBSettingsBase, BestPointMixin, InstantiationBase):
         """
         return {
             m.serialize_init_args(m)["name"]: {
-                k: v for k, v in m.serialize_init_args(m).items() if k != "name"
+                "metric_class": m.__class__,
+                **{k: v for k, v in m.serialize_init_args(m).items() if k != "name"},
             }
             for m in self.experiment.metrics.values()
         }
