@@ -4,6 +4,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+import itertools
 from collections import namedtuple
 from logging import WARN
 from typing import List
@@ -11,10 +12,14 @@ from unittest.mock import patch
 
 import pandas as pd
 from ax.core.arm import Arm
+from ax.core.metric import Metric
+from ax.core.objective import MultiObjective, Objective
+from ax.core.optimization_config import MultiObjectiveOptimizationConfig
 from ax.core.outcome_constraint import ObjectiveThreshold
 from ax.core.types import ComparisonOp
 from ax.modelbridge.registry import Models
 from ax.service.utils.report_utils import (
+    _get_metric_name_pairs,
     _get_objective_v_param_plots,
     _get_shortest_unique_suffix_dict,
     exp_to_df,
@@ -50,6 +55,31 @@ TRUE_OBJECTIVE_MEAN = 2.3456
 
 
 class ReportUtilsTest(TestCase):
+    @patch(
+        "ax.service.utils.report_utils._merge_results_if_no_duplicates",
+        autospec=True,
+        return_value=pd.DataFrame(
+            [
+                # Trial indexes are out-of-order.
+                {"arm_name": "a", "trial_index": 1},
+                {"arm_name": "b", "trial_index": 2},
+                {"arm_name": "c", "trial_index": 0},
+            ]
+        ),
+    )
+    def test_exp_to_df_ordering(self, _) -> None:
+        """
+        This test verifies that the returned data frame indexes are
+        in the same order as trial index. It mocks _merge_results_if_no_duplicates
+        to verify just the ordering of items in the final data frame.
+        """
+        exp = get_branin_experiment(with_trial=True)
+        df = exp_to_df(exp)
+        # Check that all 3 rows are in order
+        self.assertEqual(len(df), 3)
+        for idx, row in df.iterrows():
+            self.assertEqual(row["trial_index"], idx)
+
     def test_exp_to_df(self) -> None:
         # MultiTypeExperiment should fail
         exp = get_multi_type_experiment()
@@ -241,3 +271,28 @@ class ReportUtilsTest(TestCase):
             # Adds two more warnings.
             self.assertEqual(len(log.output), 3)
             self.assertIn("Skipping creation of 50 slice plots", log.output[1])
+
+    def test_get_metric_name_pairs(self) -> None:
+        exp = get_branin_experiment(with_trial=True)
+        exp._optimization_config = MultiObjectiveOptimizationConfig(
+            objective=MultiObjective(
+                objectives=[
+                    Objective(metric=Metric("m0")),
+                    Objective(metric=Metric("m1")),
+                    Objective(metric=Metric("m2")),
+                    Objective(metric=Metric("m3")),
+                    Objective(metric=Metric("m4")),
+                ]
+            )
+        )
+        with self.assertLogs(logger="ax", level=WARN) as log:
+            metric_name_pairs = _get_metric_name_pairs(experiment=exp)
+            self.assertEqual(len(log.output), 1)
+            self.assertIn(
+                "Creating pairwise Pareto plots for the first `use_n_metrics",
+                log.output[0],
+            )
+        self.assertListEqual(
+            list(metric_name_pairs),
+            list(itertools.combinations([f"m{i}" for i in range(4)], 2)),
+        )
