@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from __future__ import annotations
+
+import inspect
+import logging
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type
+from typing import Any, Dict, List, Optional, Type, TYPE_CHECKING
 
 from ax.core.arm import Arm
 from ax.core.base_trial import TrialStatus
@@ -16,6 +20,10 @@ from ax.core.trial import Trial
 from ax.modelbridge.transforms.base import Transform
 from ax.storage.botorch_modular_registry import CLASS_TO_REVERSE_REGISTRY
 from ax.storage.transform_registry import REVERSE_TRANSFORM_REGISTRY
+from ax.utils.common.kwargs import warn_on_kwargs
+from ax.utils.common.logger import get_logger
+
+logger: logging.Logger = get_logger(__name__)
 
 
 if TYPE_CHECKING:
@@ -24,7 +32,7 @@ if TYPE_CHECKING:
 
 
 def batch_trial_from_json(
-    experiment: "core.experiment.Experiment",
+    experiment: core.experiment.Experiment,
     index: int,
     trial_type: Optional[str],
     status: TrialStatus,
@@ -46,6 +54,8 @@ def batch_trial_from_json(
     ttl_seconds: Optional[int] = None,
     generation_step_index: Optional[int] = None,
     properties: Optional[Dict[str, Any]] = None,
+    stop_metadata: Optional[Dict[str, Any]] = None,
+    **kwargs: Any,
 ) -> BatchTrial:
     """Load Ax BatchTrial from JSON.
 
@@ -64,6 +74,7 @@ def batch_trial_from_json(
     batch._time_run_started = time_run_started
     batch._abandoned_reason = abandoned_reason
     batch._run_metadata = run_metadata or {}
+    batch._stop_metadata = stop_metadata or {}
     batch._generator_run_structs = generator_run_structs
     batch._runner = runner
     batch._abandoned_arms_metadata = abandoned_arms_metadata
@@ -74,11 +85,12 @@ def batch_trial_from_json(
     batch._generation_step_index = generation_step_index
     batch._properties = properties
     batch._refresh_arms_by_name()  # Trigger cache build
+    warn_on_kwargs(callable_with_kwargs=BatchTrial, **kwargs)
     return batch
 
 
 def trial_from_json(
-    experiment: "core.experiment.Experiment",
+    experiment: core.experiment.Experiment,
     index: int,
     trial_type: Optional[str],
     status: TrialStatus,
@@ -96,6 +108,8 @@ def trial_from_json(
     ttl_seconds: Optional[int] = None,
     generation_step_index: Optional[int] = None,
     properties: Optional[Dict[str, Any]] = None,
+    stop_metadata: Optional[Dict[str, Any]] = None,
+    **kwargs: Any,
 ) -> Trial:
     """Load Ax trial from JSON.
 
@@ -118,10 +132,12 @@ def trial_from_json(
     trial._time_run_started = time_run_started
     trial._abandoned_reason = abandoned_reason
     trial._run_metadata = run_metadata or {}
+    trial._stop_metadata = stop_metadata or {}
     trial._runner = runner
     trial._num_arms_created = num_arms_created
     trial._generation_step_index = generation_step_index
     trial._properties = properties or {}
+    warn_on_kwargs(callable_with_kwargs=Trial, **kwargs)
     return trial
 
 
@@ -133,6 +149,7 @@ def transform_type_from_json(object_json: Dict[str, Any]) -> Type[Transform]:
     return REVERSE_TRANSFORM_REGISTRY[index_in_registry]
 
 
+# pyre-fixme[3]: Return annotation cannot contain `Any`.
 def class_from_json(json: Dict[str, Any]) -> Type[Any]:
     """Load any class registered in `CLASS_DECODER_REGISTRY` from JSON."""
     index_in_registry = json.pop("index")
@@ -150,3 +167,34 @@ def class_from_json(json: Dict[str, Any]) -> Type[Any]:
         f"{class_path} does not have a corresponding entry in "
         "CLASS_TO_REVERSE_REGISTRY."
     )
+
+
+# pyre-fixme[3]: Return annotation cannot contain `Any`.
+# pyre-fixme[2]: Parameter annotation cannot be `Any`.
+def botorch_component_from_json(botorch_class: Any, json: Dict[str, Any]) -> Type[Any]:
+    """Load any instance of `gpytorch.Module` or descendent registered in
+    `CLASS_DECODER_REGISTRY` from state dict."""
+    class_path = json.pop("class")
+    state_dict = json.pop("state_dict")
+    init_args = inspect.signature(botorch_class).parameters
+    required_args = {p for p, v in init_args.items() if v.default is inspect._empty}
+    allowable_args = set(init_args)
+    received_args = set(state_dict)
+    missing_args = required_args - received_args
+    if missing_args:
+        raise ValueError(
+            f"Missing required initialization args {missing_args} for class "
+            f"{class_path}. For gpytorch objects, this is likely because the "
+            "object's `state_dict` method does not return the args required "
+            "for initialization."
+        )
+    extra_args = received_args - allowable_args
+    if extra_args:
+        raise ValueError(
+            f"Received unused args {extra_args} for class {class_path}. "
+            "For gpytorch objects, this is likely because the object's "
+            "`state_dict` method returns these extra args, which could "
+            "indicate that the object's state will not be fully recreated "
+            "by this serialization/deserialization method."
+        )
+    return botorch_class(**state_dict)
