@@ -217,10 +217,6 @@ class Encoder:
 
     def parameter_to_sqa(self, parameter: Parameter) -> SQAParameter:
         """Convert Ax Parameter to SQLAlchemy."""
-        if parameter.is_hierarchical:  # pragma: no cover
-            raise NotImplementedError(
-                "SQL storage is not yet implemented for hierarchical search spaces."
-            )
         # pyre-fixme[9]: Expected `Base` for 1st...typing.Type[Parameter]`.
         parameter_class: SQAParameter = self.config.class_to_sqa_class[Parameter]
         if isinstance(parameter, RangeParameter):
@@ -236,6 +232,7 @@ class Encoder:
                 digits=parameter.digits,
                 is_fidelity=parameter.is_fidelity,
                 target_value=parameter.target_value,
+                dependents=parameter.dependents if parameter.is_hierarchical else None,
             )
         elif isinstance(parameter, ChoiceParameter):
             # pyre-fixme[29]: `SQAParameter` is not a function.
@@ -249,6 +246,7 @@ class Encoder:
                 is_task=parameter.is_task,
                 is_fidelity=parameter.is_fidelity,
                 target_value=parameter.target_value,
+                dependents=parameter.dependents if parameter.is_hierarchical else None,
             )
         elif isinstance(parameter, FixedParameter):
             # pyre-fixme[29]: `SQAParameter` is not a function.
@@ -260,6 +258,7 @@ class Encoder:
                 fixed_value=parameter.value,
                 is_fidelity=parameter.is_fidelity,
                 target_value=parameter.target_value,
+                dependents=parameter.dependents if parameter.is_hierarchical else None,
             )
         else:
             raise SQAEncodeError(
