@@ -1,25 +1,33 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Any, List, Optional, Type, cast
+from math import ceil
+from typing import Any, cast, Dict, List, Optional, Type
 
 from ax.core.experiment import Experiment
 from ax.core.generator_run import GeneratorRun
+from ax.core.trial import Trial
+from ax.exceptions.core import ObjectNotFoundError
 from ax.modelbridge.generation_strategy import GenerationStrategy
 from ax.storage.sqa_store.db import session_scope
 from ax.storage.sqa_store.decoder import Decoder
+from ax.storage.sqa_store.reduced_state import (
+    get_query_options_to_defer_immutable_duplicates,
+    get_query_options_to_defer_large_model_cols,
+)
 from ax.storage.sqa_store.sqa_classes import (
     SQAExperiment,
     SQAGenerationStrategy,
     SQAGeneratorRun,
+    SQATrial,
 )
 from ax.storage.sqa_store.sqa_config import SQAConfig
 from ax.utils.common.constants import Keys
 from ax.utils.common.typeutils import not_none
-from sqlalchemy.orm import defaultload, lazyload
+from sqlalchemy.orm import defaultload, lazyload, noload
 
 
 # ---------------------------- Loading `Experiment`. ---------------------------
@@ -29,6 +37,7 @@ def load_experiment(
     experiment_name: str,
     config: Optional[SQAConfig] = None,
     reduced_state: bool = False,
+    load_trials_in_batches_of_size: Optional[int] = None,
 ) -> Experiment:
     """Load experiment by name.
 
@@ -43,95 +52,173 @@ def load_experiment(
     config = config or SQAConfig()
     decoder = Decoder(config=config)
     return _load_experiment(
-        experiment_name=experiment_name, decoder=decoder, reduced_state=reduced_state
+        experiment_name=experiment_name,
+        decoder=decoder,
+        reduced_state=reduced_state,
+        load_trials_in_batches_of_size=load_trials_in_batches_of_size,
     )
 
 
 def _load_experiment(
-    experiment_name: str, decoder: Decoder, reduced_state: bool = False
+    experiment_name: str,
+    decoder: Decoder,
+    reduced_state: bool = False,
+    load_trials_in_batches_of_size: Optional[int] = None,
+    ax_object_field_overrides: Optional[Dict[str, Any]] = None,
 ) -> Experiment:
     """Load experiment by name, using given Decoder instance.
 
     1) Get SQLAlchemy object from DB.
     2) Convert to corresponding Ax object.
+
+    Args:
+        experiment_name: Name of the experiment
+        decoder: Decoder used to convert SQAlchemy objects into Ax objects
+        reduced_state: Whether to load experiment and generation strategy
+        load_trials_in_batches_of_size: Number of trials to be fetched from database
+            per batch
+        ax_object_field_overrides: Mapping of object types to mapping of fields
+            to override values loaded objects will all be instantiated with fields
+            set to override value
+            current valid object types are: "runner"
+
     """
     # pyre-ignore Incompatible variable type [9]: exp_sqa_class is declared to have type
     # `Type[SQAExperiment]` but is used as type `Type[ax.storage.sqa_store.db.SQABase]`
     exp_sqa_class: Type[SQAExperiment] = decoder.config.class_to_sqa_class[Experiment]
+    # pyre-ignore Incompatible variable type [9]: trial_sqa_class is decl. to have type
+    # `Type[SQATrial]` but is used as type `Type[ax.storage.sqa_store.db.SQABase]`
+    trial_sqa_class: Type[SQATrial] = decoder.config.class_to_sqa_class[Trial]
 
     if reduced_state:
-        return decoder.experiment_from_sqa(
-            experiment_sqa=_get_experiment_sqa_reduced_state(
-                experiment_name=experiment_name, exp_sqa_class=exp_sqa_class
-            ),
-            reduced_state=reduced_state,
+        _get_experiment_sqa_func = _get_experiment_sqa_reduced_state
+
+    else:
+        imm_OC_and_SS = _get_experiment_immutable_opt_config_and_search_space(
+            experiment_name=experiment_name, exp_sqa_class=exp_sqa_class
         )
 
-    immutable_opt_config_and_search_space = (
-        _get_experiment_immutable_opt_config_and_search_space(
-            experiment_name=experiment_name, exp_sqa_class=exp_sqa_class
+        _get_experiment_sqa_func = (
+            _get_experiment_sqa_immutable_opt_config_and_search_space
+            if imm_OC_and_SS
+            else _get_experiment_sqa
         )
+
+    experiment_sqa = _get_experiment_sqa_func(
+        experiment_name=experiment_name,
+        exp_sqa_class=exp_sqa_class,
+        trial_sqa_class=trial_sqa_class,
+        load_trials_in_batches_of_size=load_trials_in_batches_of_size,
+    )
+
+    return decoder.experiment_from_sqa(
+        experiment_sqa=experiment_sqa,
+        reduced_state=reduced_state,
+        ax_object_field_overrides=ax_object_field_overrides,
     )
-    if immutable_opt_config_and_search_space:
-        experiment_sqa = _get_experiment_sqa_immutable_opt_config_and_search_space(
-            experiment_name=experiment_name, exp_sqa_class=exp_sqa_class
-        )
-    else:
-        experiment_sqa = _get_experiment_sqa(
-            experiment_name=experiment_name, exp_sqa_class=exp_sqa_class
-        )
-    return decoder.experiment_from_sqa(experiment_sqa=experiment_sqa)
 
 
 def _get_experiment_sqa(
     experiment_name: str,
     exp_sqa_class: Type[SQAExperiment],
-    query_options: Optional[List[Any]] = None,
+    trial_sqa_class: Type[SQATrial],
+    # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
+    trials_query_options: Optional[List[Any]] = None,
+    load_trials_in_batches_of_size: Optional[int] = None,
 ) -> SQAExperiment:
     """Obtains SQLAlchemy experiment object from DB."""
     with session_scope() as session:
-        query = session.query(exp_sqa_class).filter_by(name=experiment_name)
-        if query_options is not None:
-            query = query.options(*query_options)
+        query = (
+            session.query(exp_sqa_class).filter_by(name=experiment_name)
+            # Delay loading trials to a separate call to `_get_trials_sqa` below
+            .options(noload("trials"))
+        )
         sqa_experiment = query.one_or_none()
-        if sqa_experiment is None:
-            raise ValueError(f"Experiment '{experiment_name}' not found.")
+
+    if sqa_experiment is None:
+        raise ObjectNotFoundError(f"Experiment '{experiment_name}' not found.")
+
+    sqa_trials = _get_trials_sqa(
+        experiment_id=sqa_experiment.id,
+        trial_sqa_class=trial_sqa_class,
+        trials_query_options=trials_query_options,
+        load_trials_in_batches_of_size=load_trials_in_batches_of_size,
+    )
+
+    sqa_experiment.trials = sqa_trials
+
     return sqa_experiment
 
 
+def _get_trials_sqa(
+    experiment_id: int,
+    trial_sqa_class: Type[SQATrial],
+    load_trials_in_batches_of_size: Optional[int] = None,
+    # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
+    trials_query_options: Optional[List[Any]] = None,
+) -> List[SQATrial]:
+
+    """Obtains SQLAlchemy trial objects for given experiment ID from DB,
+    optionally in mini-batches and with specified query options.
+    """
+    with session_scope() as session:
+        query = session.query(trial_sqa_class.id).filter_by(experiment_id=experiment_id)
+        trial_db_ids = query.all()
+        trial_db_ids = [db_id_tuple[0] for db_id_tuple in trial_db_ids]
+
+    if len(trial_db_ids) == 0:
+        return []
+
+    batch_size = (
+        len(trial_db_ids)
+        if load_trials_in_batches_of_size is None
+        else load_trials_in_batches_of_size
+    )
+
+    sqa_trials = []
+    for i in range(ceil(len(trial_db_ids) / batch_size)):
+        mini_batch_db_ids = trial_db_ids[batch_size * i : batch_size * (i + 1)]
+        with session_scope() as session:
+            query = session.query(trial_sqa_class).filter(
+                trial_sqa_class.id.in_(mini_batch_db_ids)  # pyre-ignore[16]
+            )
+
+            if trials_query_options is not None:
+                query = query.options(*trials_query_options)
+
+            sqa_trials.extend(query.all())
+
+    return sqa_trials
+
+
 def _get_experiment_sqa_reduced_state(
-    experiment_name: str, exp_sqa_class: Type[SQAExperiment]
+    experiment_name: str,
+    exp_sqa_class: Type[SQAExperiment],
+    trial_sqa_class: Type[SQATrial],
+    load_trials_in_batches_of_size: Optional[int] = None,
 ) -> SQAExperiment:
     """Obtains most of the SQLAlchemy experiment object from DB, with some attributes
     (model state on generator runs, abandoned arms) omitted. Used for loading
     large experiments, in cases where model state history is not required.
     """
+    options = get_query_options_to_defer_immutable_duplicates()
+    options.append(lazyload("abandoned_arms"))
+    options.extend(get_query_options_to_defer_large_model_cols())
+
     return _get_experiment_sqa(
         experiment_name=experiment_name,
         exp_sqa_class=exp_sqa_class,
-        query_options=[
-            lazyload("trials.generator_runs.parameters"),
-            lazyload("trials.generator_runs.parameter_constraints"),
-            lazyload("trials.generator_runs.metrics"),
-            lazyload("trials.abandoned_arms"),
-            defaultload(exp_sqa_class.trials)
-            .defaultload("generator_runs")
-            .defer("model_kwargs"),
-            defaultload(exp_sqa_class.trials)
-            .defaultload("generator_runs")
-            .defer("bridge_kwargs"),
-            defaultload(exp_sqa_class.trials)
-            .defaultload("generator_runs")
-            .defer("model_state_after_gen"),
-            defaultload(exp_sqa_class.trials)
-            .defaultload("generator_runs")
-            .defer("gen_metadata"),
-        ],
+        trial_sqa_class=trial_sqa_class,
+        trials_query_options=options,
+        load_trials_in_batches_of_size=load_trials_in_batches_of_size,
     )
 
 
 def _get_experiment_sqa_immutable_opt_config_and_search_space(
-    experiment_name: str, exp_sqa_class: Type[SQAExperiment]
+    experiment_name: str,
+    exp_sqa_class: Type[SQAExperiment],
+    trial_sqa_class: Type[SQATrial],
+    load_trials_in_batches_of_size: Optional[int] = None,
 ) -> SQAExperiment:
     """For experiments where the search space and opt config are
     immutable, we don't store copies of search space and opt config
@@ -142,11 +229,9 @@ def _get_experiment_sqa_immutable_opt_config_and_search_space(
     return _get_experiment_sqa(
         experiment_name=experiment_name,
         exp_sqa_class=exp_sqa_class,
-        query_options=[
-            lazyload("trials.generator_runs.parameters"),
-            lazyload("trials.generator_runs.parameter_constraints"),
-            lazyload("trials.generator_runs.metrics"),
-        ],
+        trial_sqa_class=trial_sqa_class,
+        trials_query_options=get_query_options_to_defer_immutable_duplicates(),
+        load_trials_in_batches_of_size=load_trials_in_batches_of_size,
     )
 
 
@@ -163,7 +248,7 @@ def _get_experiment_immutable_opt_config_and_search_space(
             .one_or_none()
         )
         if sqa_experiment_properties is None:
-            raise ValueError(f"Experiment '{experiment_name}' not found.")
+            raise ObjectNotFoundError(f"Experiment '{experiment_name}' not found.")
 
     sqa_experiment_properties = sqa_experiment_properties[0] or {}
     return sqa_experiment_properties.get(
@@ -240,7 +325,7 @@ def _load_generation_strategy_by_experiment_name(
         experiment_name=experiment_name, decoder=decoder
     )
     if gs_id is None:
-        raise ValueError(
+        raise ObjectNotFoundError(
             f"Experiment {experiment_name} does not have a generation strategy "
             "attached to it."
         )
@@ -323,6 +408,7 @@ def _get_generation_strategy_id(
 def _get_generation_strategy_sqa(
     gs_id: int,
     decoder: Decoder,
+    # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
     query_options: Optional[List[Any]] = None,
 ) -> SQAGenerationStrategy:
     """Obtains the SQLAlchemy generation strategy object from DB."""
@@ -336,7 +422,7 @@ def _get_generation_strategy_sqa(
             query = query.options(*query_options)
         gs_sqa = query.one_or_none()
     if gs_sqa is None:
-        raise ValueError(f"Generation strategy with ID #{gs_id} not found.")
+        raise ObjectNotFoundError(f"Generation strategy with ID #{gs_id} not found.")
     return gs_sqa
 
 
