@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -15,6 +15,7 @@ class DomainType(enum.Enum):
     FIXED: int = 0
     RANGE: int = 1
     CHOICE: int = 2
+    ENVIRONMENTAL_RANGE: int = 3
 
 
 class MetricIntent(enum.Enum):
@@ -29,6 +30,7 @@ class MetricIntent(enum.Enum):
     SCALARIZED_OUTCOME_CONSTRAINT: str = "scalarized_outcome_constraint"
     OBJECTIVE_THRESHOLD: str = "objective_threshold"
     TRACKING: str = "tracking"
+    RISK_MEASURE: str = "risk_measure"
 
 
 class ParameterConstraintType(enum.Enum):
@@ -41,3 +43,4 @@ class ParameterConstraintType(enum.Enum):
     LINEAR: int = 0
     ORDER: int = 1
     SUM: int = 2
+    DISTRIBUTION: int = 3
