@@ -1,10 +1,21 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 from enum import Enum, unique
+from typing import Tuple
+
+
+# -------------------------- Warnings --------------------------
+
+
+EXPERIMENT_IS_TEST_WARNING = (
+    "The is_test flag has been set to True. "
+    "This flag is meant purely for development and integration testing purposes. "
+    "If you are running a live experiment, please set this flag to False"
+)
 
 
 # -------------------------- Error messages --------------------------
@@ -40,6 +51,7 @@ class Keys(str, Enum):
     FIDELITY_FEATURES = "fidelity_features"
     FIDELITY_WEIGHTS = "fidelity_weights"
     FRAC_RANDOM = "frac_random"
+    FULL_PARAMETERIZATION = "full_parameterization"
     IMMUTABLE_SEARCH_SPACE_AND_OPT_CONF = "immutable_search_space_and_opt_config"
     MAXIMIZE = "maximize"
     METADATA = "metadata"
@@ -66,3 +78,7 @@ class Keys(str, Enum):
     TASK_FEATURES = "task_features"
     WARM_START_REFITTING = "warm_start_refitting"
     X_BASELINE = "X_baseline"
+
+
+DEFAULT_WINSORIZATION_LIMITS_MINIMIZATION: Tuple[float, float] = (0.0, 0.2)
+DEFAULT_WINSORIZATION_LIMITS_MAXIMIZATION: Tuple[float, float] = (0.2, 0.0)
