@@ -1,17 +1,18 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 from inspect import Parameter, signature
+
+from logging import Logger
 from typing import Any, Callable, Dict, Iterable, List, Optional
 
 from ax.utils.common.logger import get_logger
 from typeguard import check_type
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 TKwargs = Dict[str, Any]
 
@@ -39,13 +40,16 @@ def consolidate_kwargs(
 
 
 def get_function_argument_names(
-    function: Callable, omit: Optional[List[str]] = None
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
+    function: Callable,
+    omit: Optional[List[str]] = None,
 ) -> List[str]:
     """Extract parameter names from function signature."""
     omit = omit or []
     return [p for p in signature(function).parameters.keys() if p not in omit]
 
 
+# pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
 def get_function_default_arguments(function: Callable) -> Dict[str, Any]:
     """Extract default arguments from function signature."""
     params = signature(function).parameters
@@ -54,6 +58,7 @@ def get_function_default_arguments(function: Callable) -> Dict[str, Any]:
     }
 
 
+# pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
 def validate_kwarg_typing(typed_callables: List[Callable], **kwargs: Any) -> None:
     """Check if keywords in kwargs exist in any of the typed_callables and
     if the type of each keyword value matches the type of corresponding arg in one of
@@ -92,3 +97,30 @@ def validate_kwarg_typing(typed_callables: List[Callable], **kwargs: Any) -> Non
         raise ValueError(
             f"Arguments {extra_keywords} are not expected by any of {typed_callables}."
         )
+
+
+# pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
+def warn_on_kwargs(callable_with_kwargs: Callable, **kwargs: Any) -> None:
+    """Log a warning when a decoder function receives unexpected kwargs.
+
+    NOTE: This mainly caters to the use case where an older version of Ax is
+    used to decode objects, serialized to JSON by a newer version of Ax (and
+    therefore potentially containing new fields). In that case, the decoding
+    function should not fail when encountering those additional fields, but
+    rather just ignore them and log a warning using this function.
+    """
+    if kwargs:
+        logger.warning(
+            "Found unexpected kwargs: %s while calling %s "
+            "from JSON. These kwargs will be ignored.",
+            kwargs,
+            callable_with_kwargs,
+        )
+
+
+# pyre-fixme[3]: Return annotation cannot be `Any`.
+# pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
+def filter_kwargs(function: Callable, **kwargs: Any) -> Any:
+    """Filter out kwargs that are not applicable for a given function.
+    Return a copy of given kwargs dict with only the required kwargs."""
+    return {k: v for k, v in kwargs.items() if k in signature(function).parameters}
