@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -17,26 +17,28 @@ from ax.utils.common.testutils import TestCase
 
 
 class EqualityTest(TestCase):
-    def testEqualityTypechecker(self):
+    def testEqualityTypechecker(self) -> None:
         @equality_typechecker
+        # pyre-fixme[3]: Return type must be annotated.
+        # pyre-fixme[2]: Parameter must be annotated.
         def eq(x, y):
             return x == y
 
         self.assertFalse(eq(5, 5.0))
         self.assertTrue(eq(5, 5))
 
-    def testListsEquals(self):
+    def testListsEquals(self) -> None:
         self.assertFalse(same_elements([0], [0, 1]))
         self.assertFalse(same_elements([1, 0], [0, 2]))
         self.assertTrue(same_elements([1, 0], [0, 1]))
 
-    def testDatetimeEquals(self):
+    def testDatetimeEquals(self) -> None:
         now = datetime.now()
         self.assertTrue(datetime_equals(None, None))
         self.assertFalse(datetime_equals(None, now))
         self.assertTrue(datetime_equals(now, now))
 
-    def testDataframeEquals(self):
+    def testDataframeEquals(self) -> None:
         pd1 = pd.DataFrame.from_records([{"x": 100, "y": 200}])
         pd2 = pd.DataFrame.from_records([{"y": 200, "x": 100}])
         pd3 = pd.DataFrame.from_records([{"x": 100, "y": 300}])
