@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -14,7 +14,7 @@ from ax.utils.common.testutils import TestCase
 
 
 class TestRetryDecorator(TestCase):
-    def test_default_return(self):
+    def test_default_return(self) -> None:
         """
         Tests if the decorator correctly returns the default value.
         """
@@ -23,13 +23,13 @@ class TestRetryDecorator(TestCase):
             @retry_on_exception(
                 suppress_all_errors=True, default_return_on_suppression="SUCCESS"
             )
-            def error_throwing_function(self):
-                raise Exception("ERROR THROWN FOR TESTING. SHOULD HAVE BEEN CAUGHT")
+            def error_throwing_function(self) -> None:
+                raise RuntimeError("ERROR THROWN FOR TESTING. SHOULD HAVE BEEN CAUGHT")
 
         decorator_tester = DecoratorTester()
         self.assertEqual("SUCCESS", decorator_tester.error_throwing_function())
 
-    def test_kwarg_passage(self):
+    def test_kwarg_passage(self) -> None:
         """
         Tests if the decorator correctly takes the suppress all errors
         flag from the kwargs of the decorated function.
@@ -42,7 +42,7 @@ class TestRetryDecorator(TestCase):
             ):
                 # Testing that kwargs get passed down correctly
                 self.assertEqual(extra_kwarg, "abcd")
-                raise Exception("ERROR THROWN FOR TESTING. SHOULD HAVE BEEN CAUGHT")
+                raise RuntimeError("ERROR THROWN FOR TESTING. SHOULD HAVE BEEN CAUGHT")
 
         decorator_tester = DecoratorTester()
         self.assertEqual(
@@ -52,7 +52,7 @@ class TestRetryDecorator(TestCase):
             ),
         )
 
-    def test_message_checking(self):
+    def test_message_checking(self) -> None:
         """
         Tests if the decorator correctly checks the list of messages
         provided for which you may suppress the error.
@@ -69,7 +69,7 @@ class TestRetryDecorator(TestCase):
                 logger=logger,
                 suppress_all_errors=True,
             )
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The exception thrown below should be caught and handled since it
                 # has the keywords we want
                 raise RuntimeError("Hello World")
@@ -77,7 +77,7 @@ class TestRetryDecorator(TestCase):
         decorator_tester = DecoratorTester()
         self.assertEqual("SUCCESS", decorator_tester.error_throwing_function())
 
-    def test_empty_exception_type_tuple(self):
+    def test_empty_exception_type_tuple(self) -> None:
         """
         Tests if the decorator correctly handles an empty list
         of exception types to suppress.
@@ -93,7 +93,7 @@ class TestRetryDecorator(TestCase):
                 logger=logger,
                 suppress_all_errors=False,
             )
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The exception thrown below should not be caught
                 # because we specified an empty list.
                 raise RuntimeError("Hello World")
@@ -102,7 +102,7 @@ class TestRetryDecorator(TestCase):
         with self.assertRaises(RuntimeError):
             decorator_tester.error_throwing_function()
 
-    def test_message_checking_fail(self):
+    def test_message_checking_fail(self) -> None:
         """
         Tests if the decorator correctly checks the list of messages
         provided. In this case, we check if it correctly fails.
@@ -114,7 +114,7 @@ class TestRetryDecorator(TestCase):
                 check_message_contains=["Hello", "World"],
                 exception_types=(RuntimeError,),
             )
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The execption thrown below should NOT be caught as it does not
                 # contain the keywords we want
                 raise RuntimeError
@@ -123,24 +123,24 @@ class TestRetryDecorator(TestCase):
         with self.assertRaises(RuntimeError):
             decorator_tester.error_throwing_function()
 
-    def test_retry_mechanism(self):
+    def test_retry_mechanism(self) -> None:
         """
         Tests if the decorator retries sufficient number of times
         """
 
         class DecoratorTester:
-            def __init__(self):
+            def __init__(self) -> None:
                 self.retries_done = 0
 
             @retry_on_exception(retries=4)
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The call below will succeed only on the 3rd try
                 return self.succeed_on_3rd_try()
 
-            def succeed_on_3rd_try(self):
+            def succeed_on_3rd_try(self) -> None:
                 if self.retries_done < 2:
                     self.retries_done += 1
-                    raise Exception(
+                    raise RuntimeError(
                         "This error surfacing means enough retries were not done"
                     )
                 else:
@@ -149,28 +149,28 @@ class TestRetryDecorator(TestCase):
         decorator_tester = DecoratorTester()
         self.assertEqual("SUCCESS", decorator_tester.error_throwing_function())
 
-    def test_retry_with_wait(self):
+    def test_retry_with_wait(self) -> None:
         """
         Tests if the decorator retries sufficient number of times
         """
 
         class DecoratorTester:
-            def __init__(self):
+            def __init__(self) -> None:
                 self.start_time = time.time()
 
             @retry_on_exception(retries=4, initial_wait_seconds=1)
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The call below will succeed only on the 3rd try
                 return self.succeed_after_five_seconds()
 
             @retry_on_exception(retries=4)
-            def no_wait_error_throwing_function(self):
+            def no_wait_error_throwing_function(self) -> None:
                 # The call below will succeed only on the 3rd try
                 return self.succeed_after_five_seconds()
 
-            def succeed_after_five_seconds(self):
+            def succeed_after_five_seconds(self) -> None:
                 if time.time() - self.start_time < 5:
-                    raise Exception(
+                    raise RuntimeError(
                         "This error surfacing means enough retries were not done"
                     )
                 else:
@@ -180,10 +180,10 @@ class TestRetryDecorator(TestCase):
         self.assertEqual("SUCCESS", decorator_tester.error_throwing_function())
 
         decorator_tester = DecoratorTester()
-        with self.assertRaises(Exception):
+        with self.assertRaises(RuntimeError):
             decorator_tester.no_wait_error_throwing_function()
 
-    def test_retry_mechanism_fail(self):
+    def test_retry_mechanism_fail(self) -> None:
         """
         Tests that the decorator does not retry too many times
         """
@@ -192,15 +192,15 @@ class TestRetryDecorator(TestCase):
         logger = logging.getLogger("test_retry_mechanism_fail")
 
         class DecoratorTester:
-            def __init__(self):
+            def __init__(self) -> None:
                 self.xyz = 0
 
             @retry_on_exception(retries=2, logger=logger)
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 # The call below will succeed only on the 3rd try
                 return self.succeed_on_3rd_try()
 
-            def succeed_on_3rd_try(self):
+            def succeed_on_3rd_try(self) -> None:
                 if self.xyz < 2:
                     self.xyz += 1
                     raise KeyError
@@ -211,7 +211,7 @@ class TestRetryDecorator(TestCase):
         with self.assertRaises(KeyError):
             decorator_tester.error_throwing_function()
 
-    def test_no_retry_on_exception_types(self):
+    def test_no_retry_on_exception_types(self) -> None:
         class MyRuntimeError(RuntimeError):
             pass
 
@@ -219,7 +219,7 @@ class TestRetryDecorator(TestCase):
             error_throwing_function_call_count = 0
 
             @retry_on_exception(no_retry_on_exception_types=(MyRuntimeError,))
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 self.error_throwing_function_call_count += 1
                 # The exception thrown below should NOT be caught as it does mathes
                 # an exception type in `no_retry_on_exception_type`
@@ -239,7 +239,7 @@ class TestRetryDecorator(TestCase):
                 exception_types=(RuntimeError,),
                 no_retry_on_exception_types=(MyRuntimeError,),
             )
-            def error_throwing_function(self):
+            def error_throwing_function(self) -> None:
                 self.error_throwing_function_call_count += 1
                 # The exception thrown below should NOT be caught as it does mathes
                 # an exception type in `no_retry_on_exception_type`
@@ -249,7 +249,7 @@ class TestRetryDecorator(TestCase):
         with self.assertRaises(MyRuntimeError):
             decorator_tester.error_throwing_function()
 
-    def test_on_function_with_wrapper_message(self):
+    def test_on_function_with_wrapper_message(self) -> None:
         """Tests that the decorator works on standalone functions as well as on
         instance methods.
         """
@@ -257,6 +257,8 @@ class TestRetryDecorator(TestCase):
         mock = Mock()
 
         @retry_on_exception(wrap_error_message_in="Wrapper error message")
+        # pyre-fixme[53]: Captured variable `mock` is not annotated.
+        # pyre-fixme[3]: Return type must be annotated.
         def error_throwing_function():
             mock()
             raise RuntimeError("I failed")
