@@ -267,6 +267,22 @@ def get_branin_experiment_with_timestamp_map_metric(
     return exp
 
 
+def get_test_map_data_experiment(
+    num_trials: int, num_fetches: int, num_complete: int
+) -> Experiment:
+    experiment = get_branin_experiment_with_timestamp_map_metric(rate=0.5)
+    for i in range(num_trials):
+        trial = experiment.new_trial().add_arm(arm=get_branin_arms(n=1, seed=i)[0])
+        trial.run()
+    for _ in range(num_fetches):
+        # each time we call fetch, we grab another timestamp
+        experiment.fetch_data()
+    for i in range(num_complete):
+        experiment.trials[i].mark_as(status=TrialStatus.COMPLETED)
+    experiment.attach_data(data=experiment.fetch_data())
+    return experiment
+
+
 def get_multi_type_experiment(
     add_trial_type: bool = True, add_trials: bool = False, num_arms: int = 10
 ) -> MultiTypeExperiment:
@@ -509,6 +525,8 @@ def get_experiment_with_scalarized_objective_and_outcome_constraint() -> Experim
 
 def get_hierarchical_search_space_experiment() -> Experiment:
     return Experiment(
+        name="test_experiment_hss",
+        description="test experiment with hierarchical search space",
         search_space=get_hierarchical_search_space(),
         optimization_config=get_optimization_config(),
     )
@@ -520,7 +538,7 @@ def get_experiment_with_observations(
     scalarized: bool = False,
     constrained: bool = False,
 ) -> Experiment:
-    multi_objective = len(observations[0]) > 1
+    multi_objective = (len(observations[0]) - constrained) > 1
     if multi_objective:
         metrics = [
             Metric(name="m1", lower_is_better=minimize),
@@ -551,11 +569,21 @@ def get_experiment_with_observations(
                 else None,
             )
     else:
-        if scalarized or constrained:  # pragma: no cover
+        if scalarized:  # pragma: no cover
             raise NotImplementedError
-        optimization_config = OptimizationConfig(
-            objective=Objective(metric=Metric(name="m1"), minimize=minimize)
-        )
+        objective = Objective(metric=Metric(name="m1"), minimize=minimize)
+        if constrained:
+            constraint = OutcomeConstraint(
+                metric=Metric(name="m2"),
+                op=ComparisonOp.GEQ,
+                bound=0.0,
+                relative=False,
+            )
+            optimization_config = OptimizationConfig(
+                objective=objective, outcome_constraints=[constraint]
+            )
+        else:
+            optimization_config = OptimizationConfig(objective=objective)
     exp = Experiment(
         search_space=get_search_space_for_range_values(min=0.0, max=1.0),
         optimization_config=optimization_config,
