@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
@@ -33,7 +33,7 @@ versions.sort(function(a, b) {
     if (aInt === bInt) {
       continue;
     }
-    return aInt - bInt; 
+    return aInt - bInt;
   }
   return 0;
 }).reverse();
@@ -70,7 +70,7 @@ function Versions(props) {
               <tr>
                 <td>
                   {'latest'}
-                  {' (master)'}
+                  {' (main)'}
                 </td>
                 <td>
                   <code>
